# Script to set up input conditions and run the moist energy balance model. 
# 
# a, b and b' values loaded from .npy file (saved by "EBM_tuneAB.py"). 
# Rick Russotto

import geomipFunctions as gmf
import moistEBM as ebm
import netCDF4 as nc4
import matplotlib.pyplot as plt
import numpy as np
from collections import OrderedDict #need values & keys in correct order for plot legends



# First test: run EBM in control climate. 


# Okay, according to Ting's paper, the variables specified from the GCM output in the control climate are 
# S (net solar radiation at TOA), Lc (LW cloud radiative forcing--OLR in clear sky minus OLR in all sky), 
# and Fs (net downward surface flux--I assume this is LW + SW + SH + LH). This comes from an energy budget. 
# They are zonally averaged. 

# I should have access to pretty much all these outputs, and I have already used them in the energy budget
# calculations. 

# Define dictionaries containing the relevant GCM output. Same as with the meridional energy transport 
# calculations, with the addition of clear-sky OLR. 

# CSIRO model excluded because not all output necessary for APRP was saved. 
# GISS excluded because rsuscs output is unrealistic. 


# Whether to load the energy input terms from a file
# Control climate
loadFromFile_EI_PI = OrderedDict()
loadFromFile_EI_PI['ca'] = True
loadFromFile_EI_PI['cc'] = True
loadFromFile_EI_PI['ce'] = True
loadFromFile_EI_PI['gi'] = True
loadFromFile_EI_PI['hg'] = True
loadFromFile_EI_PI['ip'] = True
loadFromFile_EI_PI['mi'] = True
loadFromFile_EI_PI['mp'] = True
loadFromFile_EI_PI['no'] = True

# Perturbation climates--full
loadFromFile_EI_G1 = OrderedDict()
loadFromFile_EI_G1['ca'] = True
loadFromFile_EI_G1['cc'] = True
loadFromFile_EI_G1['ce'] = True
loadFromFile_EI_G1['hg'] = True
loadFromFile_EI_G1['ip'] = True
loadFromFile_EI_G1['mi'] = True
loadFromFile_EI_G1['mp'] = True
loadFromFile_EI_G1['no'] = True

loadFromFile_EI_A4 = OrderedDict()
loadFromFile_EI_A4['ca'] = True
loadFromFile_EI_A4['cc'] = True
loadFromFile_EI_A4['ce'] = True
loadFromFile_EI_A4['hg'] = True
loadFromFile_EI_A4['ip'] = True
loadFromFile_EI_A4['mi'] = True
loadFromFile_EI_A4['mp'] = True
loadFromFile_EI_A4['no'] = True

# Perturbation climates--experiments 
loadFromFile_EI_APRPcloud_G1 = OrderedDict()
loadFromFile_EI_APRPcloud_G1['ca'] = True
loadFromFile_EI_APRPcloud_G1['cc'] = True
loadFromFile_EI_APRPcloud_G1['ce'] = True
loadFromFile_EI_APRPcloud_G1['hg'] = True
loadFromFile_EI_APRPcloud_G1['ip'] = True
loadFromFile_EI_APRPcloud_G1['mi'] = True
loadFromFile_EI_APRPcloud_G1['mp'] = True
loadFromFile_EI_APRPcloud_G1['no'] = True

loadFromFile_EI_APRPnoncloud_G1 = OrderedDict()
loadFromFile_EI_APRPnoncloud_G1['ca'] = True
loadFromFile_EI_APRPnoncloud_G1['cc'] = True
loadFromFile_EI_APRPnoncloud_G1['ce'] = True
loadFromFile_EI_APRPnoncloud_G1['hg'] = True
loadFromFile_EI_APRPnoncloud_G1['ip'] = True
loadFromFile_EI_APRPnoncloud_G1['mi'] = True
loadFromFile_EI_APRPnoncloud_G1['mp'] = True
loadFromFile_EI_APRPnoncloud_G1['no'] = True

loadFromFile_EI_APRPsurface_G1 = OrderedDict()
loadFromFile_EI_APRPsurface_G1['ca'] = True
loadFromFile_EI_APRPsurface_G1['cc'] = True
loadFromFile_EI_APRPsurface_G1['ce'] = True
loadFromFile_EI_APRPsurface_G1['hg'] = True
loadFromFile_EI_APRPsurface_G1['ip'] = True
loadFromFile_EI_APRPsurface_G1['mi'] = True
loadFromFile_EI_APRPsurface_G1['mp'] = True
loadFromFile_EI_APRPsurface_G1['no'] = True

loadFromFile_EI_solarForcing_G1 = OrderedDict()
loadFromFile_EI_solarForcing_G1['ca'] = True
loadFromFile_EI_solarForcing_G1['cc'] = True
loadFromFile_EI_solarForcing_G1['ce'] = True
loadFromFile_EI_solarForcing_G1['hg'] = True
loadFromFile_EI_solarForcing_G1['ip'] = True
loadFromFile_EI_solarForcing_G1['mi'] = True
loadFromFile_EI_solarForcing_G1['mp'] = True
loadFromFile_EI_solarForcing_G1['no'] = True

loadFromFile_EI_surfaceFlux_G1 = OrderedDict()
loadFromFile_EI_surfaceFlux_G1['ca'] = True
loadFromFile_EI_surfaceFlux_G1['cc'] = True
loadFromFile_EI_surfaceFlux_G1['ce'] = True
loadFromFile_EI_surfaceFlux_G1['hg'] = True
loadFromFile_EI_surfaceFlux_G1['ip'] = True
loadFromFile_EI_surfaceFlux_G1['mi'] = True
loadFromFile_EI_surfaceFlux_G1['mp'] = True
loadFromFile_EI_surfaceFlux_G1['no'] = True

loadFromFile_EI_LWCRE_G1 = OrderedDict()
loadFromFile_EI_LWCRE_G1['ca'] = True
loadFromFile_EI_LWCRE_G1['cc'] = True
loadFromFile_EI_LWCRE_G1['ce'] = True
loadFromFile_EI_LWCRE_G1['hg'] = True
loadFromFile_EI_LWCRE_G1['ip'] = True
loadFromFile_EI_LWCRE_G1['mi'] = True
loadFromFile_EI_LWCRE_G1['mp'] = True
loadFromFile_EI_LWCRE_G1['no'] = True

loadFromFile_EI_APRPcloud_A4 = OrderedDict()
loadFromFile_EI_APRPcloud_A4['ca'] = True
loadFromFile_EI_APRPcloud_A4['cc'] = True
loadFromFile_EI_APRPcloud_A4['ce'] = True
loadFromFile_EI_APRPcloud_A4['hg'] = True
loadFromFile_EI_APRPcloud_A4['ip'] = True
loadFromFile_EI_APRPcloud_A4['mi'] = True
loadFromFile_EI_APRPcloud_A4['mp'] = True
loadFromFile_EI_APRPcloud_A4['no'] = True

loadFromFile_EI_APRPnoncloud_A4 = OrderedDict()
loadFromFile_EI_APRPnoncloud_A4['ca'] = True
loadFromFile_EI_APRPnoncloud_A4['cc'] = True
loadFromFile_EI_APRPnoncloud_A4['ce'] = True
loadFromFile_EI_APRPnoncloud_A4['hg'] = True
loadFromFile_EI_APRPnoncloud_A4['ip'] = True
loadFromFile_EI_APRPnoncloud_A4['mi'] = True
loadFromFile_EI_APRPnoncloud_A4['mp'] = True
loadFromFile_EI_APRPnoncloud_A4['no'] = True

loadFromFile_EI_APRPsurface_A4 = OrderedDict()
loadFromFile_EI_APRPsurface_A4['ca'] = True
loadFromFile_EI_APRPsurface_A4['cc'] = True
loadFromFile_EI_APRPsurface_A4['ce'] = True
loadFromFile_EI_APRPsurface_A4['hg'] = True
loadFromFile_EI_APRPsurface_A4['ip'] = True
loadFromFile_EI_APRPsurface_A4['mi'] = True
loadFromFile_EI_APRPsurface_A4['mp'] = True
loadFromFile_EI_APRPsurface_A4['no'] = True

loadFromFile_EI_solarForcing_A4 = OrderedDict()
loadFromFile_EI_solarForcing_A4['ca'] = True
loadFromFile_EI_solarForcing_A4['cc'] = True
loadFromFile_EI_solarForcing_A4['ce'] = True
loadFromFile_EI_solarForcing_A4['hg'] = True
loadFromFile_EI_solarForcing_A4['ip'] = True
loadFromFile_EI_solarForcing_A4['mi'] = True
loadFromFile_EI_solarForcing_A4['mp'] = True
loadFromFile_EI_solarForcing_A4['no'] = True

loadFromFile_EI_surfaceFlux_A4 = OrderedDict()
loadFromFile_EI_surfaceFlux_A4['ca'] = True
loadFromFile_EI_surfaceFlux_A4['cc'] = True
loadFromFile_EI_surfaceFlux_A4['ce'] = True
loadFromFile_EI_surfaceFlux_A4['hg'] = True
loadFromFile_EI_surfaceFlux_A4['ip'] = True
loadFromFile_EI_surfaceFlux_A4['mi'] = True
loadFromFile_EI_surfaceFlux_A4['mp'] = True
loadFromFile_EI_surfaceFlux_A4['no'] = True

loadFromFile_EI_LWCRE_A4 = OrderedDict()
loadFromFile_EI_LWCRE_A4['ca'] = True
loadFromFile_EI_LWCRE_A4['cc'] = True
loadFromFile_EI_LWCRE_A4['ce'] = True
loadFromFile_EI_LWCRE_A4['hg'] = True
loadFromFile_EI_LWCRE_A4['ip'] = True
loadFromFile_EI_LWCRE_A4['mi'] = True
loadFromFile_EI_LWCRE_A4['mp'] = True
loadFromFile_EI_LWCRE_A4['no'] = True



# Whether to load the EBM output from a file (control climate)
loadFromFile_results_PI = OrderedDict()
loadFromFile_results_PI['ca'] = True
loadFromFile_results_PI['cc'] = True
loadFromFile_results_PI['ce'] = True
loadFromFile_results_PI['gi'] = True
loadFromFile_results_PI['hg'] = True
loadFromFile_results_PI['ip'] = True
loadFromFile_results_PI['mi'] = True
loadFromFile_results_PI['mp'] = True
loadFromFile_results_PI['no'] = True

# Whether to load the EBM output from a file (perturbation climates--full)
loadFromFile_results_G1 = OrderedDict()
loadFromFile_results_G1['ca'] = True
loadFromFile_results_G1['cc'] = True
loadFromFile_results_G1['ce'] = True
loadFromFile_results_G1['hg'] = True
loadFromFile_results_G1['ip'] = True
loadFromFile_results_G1['mi'] = True
loadFromFile_results_G1['mp'] = True
loadFromFile_results_G1['no'] = True

loadFromFile_results_A4 = OrderedDict()
loadFromFile_results_A4['ca'] = True
loadFromFile_results_A4['cc'] = True
loadFromFile_results_A4['ce'] = True
loadFromFile_results_A4['hg'] = True
loadFromFile_results_A4['ip'] = True
loadFromFile_results_A4['mi'] = True
loadFromFile_results_A4['mp'] = True
loadFromFile_results_A4['no'] = True

# Whether to load the EBM output from a file (perturbation climates--experiments)
loadFromFile_results_APRPcloud_G1 = OrderedDict()
loadFromFile_results_APRPcloud_G1['ca'] = True
loadFromFile_results_APRPcloud_G1['cc'] = True
loadFromFile_results_APRPcloud_G1['ce'] = True
loadFromFile_results_APRPcloud_G1['hg'] = True
loadFromFile_results_APRPcloud_G1['ip'] = True
loadFromFile_results_APRPcloud_G1['mi'] = True
loadFromFile_results_APRPcloud_G1['mp'] = True
loadFromFile_results_APRPcloud_G1['no'] = True

loadFromFile_results_APRPnoncloud_G1 = OrderedDict()
loadFromFile_results_APRPnoncloud_G1['ca'] = True
loadFromFile_results_APRPnoncloud_G1['cc'] = True
loadFromFile_results_APRPnoncloud_G1['ce'] = True
loadFromFile_results_APRPnoncloud_G1['hg'] = True
loadFromFile_results_APRPnoncloud_G1['ip'] = True
loadFromFile_results_APRPnoncloud_G1['mi'] = True
loadFromFile_results_APRPnoncloud_G1['mp'] = True
loadFromFile_results_APRPnoncloud_G1['no'] = True

loadFromFile_results_APRPsurface_G1 = OrderedDict()
loadFromFile_results_APRPsurface_G1['ca'] = True
loadFromFile_results_APRPsurface_G1['cc'] = True
loadFromFile_results_APRPsurface_G1['ce'] = True
loadFromFile_results_APRPsurface_G1['hg'] = True
loadFromFile_results_APRPsurface_G1['ip'] = True
loadFromFile_results_APRPsurface_G1['mi'] = True
loadFromFile_results_APRPsurface_G1['mp'] = True
loadFromFile_results_APRPsurface_G1['no'] = True

loadFromFile_results_solarForcing_G1 = OrderedDict()
loadFromFile_results_solarForcing_G1['ca'] = True
loadFromFile_results_solarForcing_G1['cc'] = True
loadFromFile_results_solarForcing_G1['ce'] = True
loadFromFile_results_solarForcing_G1['hg'] = True
loadFromFile_results_solarForcing_G1['ip'] = True
loadFromFile_results_solarForcing_G1['mi'] = True
loadFromFile_results_solarForcing_G1['mp'] = True
loadFromFile_results_solarForcing_G1['no'] = True

loadFromFile_results_surfaceFlux_G1 = OrderedDict()
loadFromFile_results_surfaceFlux_G1['ca'] = True
loadFromFile_results_surfaceFlux_G1['cc'] = True
loadFromFile_results_surfaceFlux_G1['ce'] = True
loadFromFile_results_surfaceFlux_G1['hg'] = True
loadFromFile_results_surfaceFlux_G1['ip'] = True
loadFromFile_results_surfaceFlux_G1['mi'] = True
loadFromFile_results_surfaceFlux_G1['mp'] = True
loadFromFile_results_surfaceFlux_G1['no'] = True

loadFromFile_results_LWCRE_G1 = OrderedDict()
loadFromFile_results_LWCRE_G1['ca'] = True
loadFromFile_results_LWCRE_G1['cc'] = True
loadFromFile_results_LWCRE_G1['ce'] = True
loadFromFile_results_LWCRE_G1['hg'] = True
loadFromFile_results_LWCRE_G1['ip'] = True
loadFromFile_results_LWCRE_G1['mi'] = True
loadFromFile_results_LWCRE_G1['mp'] = True
loadFromFile_results_LWCRE_G1['no'] = True

loadFromFile_results_greenhouse_G1 = OrderedDict()
loadFromFile_results_greenhouse_G1['ca'] = True
loadFromFile_results_greenhouse_G1['cc'] = True
loadFromFile_results_greenhouse_G1['ce'] = True
loadFromFile_results_greenhouse_G1['hg'] = True
loadFromFile_results_greenhouse_G1['ip'] = True
loadFromFile_results_greenhouse_G1['mi'] = True
loadFromFile_results_greenhouse_G1['mp'] = True
loadFromFile_results_greenhouse_G1['no'] = True

loadFromFile_results_APRPcloud_A4 = OrderedDict()
loadFromFile_results_APRPcloud_A4['ca'] = True
loadFromFile_results_APRPcloud_A4['cc'] = True
loadFromFile_results_APRPcloud_A4['ce'] = True
loadFromFile_results_APRPcloud_A4['hg'] = True
loadFromFile_results_APRPcloud_A4['ip'] = True
loadFromFile_results_APRPcloud_A4['mi'] = True
loadFromFile_results_APRPcloud_A4['mp'] = True
loadFromFile_results_APRPcloud_A4['no'] = True

loadFromFile_results_APRPnoncloud_A4 = OrderedDict()
loadFromFile_results_APRPnoncloud_A4['ca'] = True
loadFromFile_results_APRPnoncloud_A4['cc'] = True
loadFromFile_results_APRPnoncloud_A4['ce'] = True
loadFromFile_results_APRPnoncloud_A4['hg'] = True
loadFromFile_results_APRPnoncloud_A4['ip'] = True
loadFromFile_results_APRPnoncloud_A4['mi'] = True
loadFromFile_results_APRPnoncloud_A4['mp'] = True
loadFromFile_results_APRPnoncloud_A4['no'] = True

loadFromFile_results_APRPsurface_A4 = OrderedDict()
loadFromFile_results_APRPsurface_A4['ca'] = True
loadFromFile_results_APRPsurface_A4['cc'] = True
loadFromFile_results_APRPsurface_A4['ce'] = True
loadFromFile_results_APRPsurface_A4['hg'] = True
loadFromFile_results_APRPsurface_A4['ip'] = True
loadFromFile_results_APRPsurface_A4['mi'] = True
loadFromFile_results_APRPsurface_A4['mp'] = True
loadFromFile_results_APRPsurface_A4['no'] = True

loadFromFile_results_solarForcing_A4 = OrderedDict()
loadFromFile_results_solarForcing_A4['ca'] = True
loadFromFile_results_solarForcing_A4['cc'] = True
loadFromFile_results_solarForcing_A4['ce'] = True
loadFromFile_results_solarForcing_A4['hg'] = True
loadFromFile_results_solarForcing_A4['ip'] = True
loadFromFile_results_solarForcing_A4['mi'] = True
loadFromFile_results_solarForcing_A4['mp'] = True
loadFromFile_results_solarForcing_A4['no'] = True

loadFromFile_results_surfaceFlux_A4 = OrderedDict()
loadFromFile_results_surfaceFlux_A4['ca'] = True
loadFromFile_results_surfaceFlux_A4['cc'] = True
loadFromFile_results_surfaceFlux_A4['ce'] = True
loadFromFile_results_surfaceFlux_A4['hg'] = True
loadFromFile_results_surfaceFlux_A4['ip'] = True
loadFromFile_results_surfaceFlux_A4['mi'] = True
loadFromFile_results_surfaceFlux_A4['mp'] = True
loadFromFile_results_surfaceFlux_A4['no'] = True

loadFromFile_results_LWCRE_A4 = OrderedDict()
loadFromFile_results_LWCRE_A4['ca'] = True
loadFromFile_results_LWCRE_A4['cc'] = True
loadFromFile_results_LWCRE_A4['ce'] = True
loadFromFile_results_LWCRE_A4['hg'] = True
loadFromFile_results_LWCRE_A4['ip'] = True
loadFromFile_results_LWCRE_A4['mi'] = True
loadFromFile_results_LWCRE_A4['mp'] = True
loadFromFile_results_LWCRE_A4['no'] = True

loadFromFile_results_greenhouse_A4 = OrderedDict()
loadFromFile_results_greenhouse_A4['ca'] = True
loadFromFile_results_greenhouse_A4['cc'] = True
loadFromFile_results_greenhouse_A4['ce'] = True
loadFromFile_results_greenhouse_A4['hg'] = True
loadFromFile_results_greenhouse_A4['ip'] = True
loadFromFile_results_greenhouse_A4['mi'] = True
loadFromFile_results_greenhouse_A4['mp'] = True
loadFromFile_results_greenhouse_A4['no'] = True

#Paths to relevant flux output in control and perturbation climates:

#Define paths to files
folder = '../nobackup/'         
folderCCSM = '../nobackup/CCSM4_fluxes_from_NCAR/' #For corrected rlut output
folderCESM = '../nobackup/CESM_corrected/'
folderNor = '../nobackup/NorESM_corrected_rlut/'


fluxPaths_PI = OrderedDict()
fluxPaths_PI['ca'] = {'rsdt': folder+'rsdt_Amon_CanESM2_piControl_r1i1p1_201501-231012.nc', 
                      'rsut': folder+'rsut_Amon_CanESM2_piControl_r1i1p1_201501-231012.nc',
                      'rlut': folder+'rlut_Amon_CanESM2_piControl_r1i1p1_201501-231012.nc',
                      'rlutcs': folder+'rlutcs_Amon_CanESM2_piControl_r1i1p1_201501-231012.nc',
                      'rsds': folder+'rsds_Amon_CanESM2_piControl_r1i1p1_201501-231012.nc',
                      'rlds': folder+'rlds_Amon_CanESM2_piControl_r1i1p1_201501-231012.nc',
                      'rsus': folder+'rsus_Amon_CanESM2_piControl_r1i1p1_201501-231012.nc',
                      'rlus': folder+'rlus_Amon_CanESM2_piControl_r1i1p1_201501-231012.nc',
                      'hfls': folder+'hfls_Amon_CanESM2_piControl_r1i1p1_201501-231012.nc',
                      'hfss': folder+'hfss_Amon_CanESM2_piControl_r1i1p1_201501-231012.nc',
                      'prsn': folder+'prsn_Amon_CanESM2_piControl_r1i1p1_201501-231012.nc',
                      }
fluxPaths_PI['cc'] = {'rsdt': folder+'rsdt_Amon_CCSM4_piControl_r1i1p1_080001-130012.nc',
                      'rsut': folder+'rsut_Amon_CCSM4_piControl_r1i1p1_080001-130012.nc',
                      'rlut': folderCCSM+'rlut_Amon_CCSM4_piControl_r1i1p1_080001-130012.nc', 
                      'rlutcs': folderCCSM+'rlutcs_Amon_CCSM4_piControl_r1i1p1_080001-130012.nc', 
                      'rsds': folder+'rsds_Amon_CCSM4_piControl_r1i1p1_080001-130012.nc',
                      'rlds': folder+'rlds_Amon_CCSM4_piControl_r1i1p1_080001-130012.nc',
                      'rsus': folder+'rsus_Amon_CCSM4_piControl_r1i1p1_080001-130012.nc',
                      'rlus': folder+'rlus_Amon_CCSM4_piControl_r1i1p1_080001-130012.nc',
                      'hfls': folder+'hfls_Amon_CCSM4_piControl_r1i1p1_080001-130012.nc',
                      'hfss': folder+'hfss_Amon_CCSM4_piControl_r1i1p1_080001-130012.nc',
                      'prsn': folder+'prsn_Amon_CCSM4_piControl_r1i1p1_080001-130012.nc',
                      }
fluxPaths_PI['ce'] = {'rsdt': folder+'rsdt_Amon_CESM1-CAM5-1-FV2_piControl_r1i1p1_000101-005012.nc',
                      'rsut': folder+'rsut_Amon_CESM1-CAM5-1-FV2_piControl_r1i1p1_000101-005012.nc',
                      'rlut': folderCESM+'rlut_Amon_CESM1-CAM5.1-FV2_piControl_r1i1p1_000101-005012.nc', 
                      'rlutcs': folder+'rlutcs_Amon_CESM1-CAM5-1-FV2_piControl_r1i1p1_000101-005012.nc', 
                      'rsds': folder+'rsds_Amon_CESM1-CAM5-1-FV2_piControl_r1i1p1_000101-005012.nc',
                      'rlds': folder+'rlds_Amon_CESM1-CAM5-1-FV2_piControl_r1i1p1_000101-005012.nc',
                      'rsus': folder+'rsus_Amon_CESM1-CAM5-1-FV2_piControl_r1i1p1_000101-005012.nc',
                      'rlus': folder+'rlus_Amon_CESM1-CAM5-1-FV2_piControl_r1i1p1_000101-005012.nc',
                      'hfls': folder+'hfls_Amon_CESM1-CAM5-1-FV2_piControl_r1i1p1_000101-005012.nc',
                      'hfss': folder+'hfss_Amon_CESM1-CAM5-1-FV2_piControl_r1i1p1_000101-005012.nc',
                      'prsn': folder+'prsn_Amon_CESM1-CAM5-1-FV2_piControl_r1i1p1_000101-005012.nc',
                      }                      
fluxPaths_PI['gi'] = {'hfls': folder+'hfls_Amon_GISS-E2-R_piControl_r1i1p1_185001-191912.nc', 
                      'hfss': folder+'hfss_Amon_GISS-E2-R_piControl_r1i1p1_185001-191912.nc',  
                      'rlds': folder+'rlds_Amon_GISS-E2-R_piControl_r1i1p1_185001-191912.nc', 
                      'rlus': folder+'rlus_Amon_GISS-E2-R_piControl_r1i1p1_185001-191912.nc', 
                      'rlut': folder+'rlut_Amon_GISS-E2-R_piControl_r1i1p1_185001-191912.nc', 
                      'rlutcs': folder+'rlutcs_Amon_GISS-E2-R_piControl_r1i1p1_185001-191912.nc',
                      'rsds': folder+'rsds_Amon_GISS-E2-R_piControl_r1i1p1_185001-191912.nc', 
                      'rsdt': folder+'rsdt_Amon_GISS-E2-R_piControl_r1i1p1_185001-191912.nc', 
                      'rsus': folder+'rsus_Amon_GISS-E2-R_piControl_r1i1p1_185001-191912.nc', 
                      'rsut': folder+'rsut_Amon_GISS-E2-R_piControl_r1i1p1_185001-191912.nc',
                      'prsn': folder+'prsn_Amon_GISS-E2-R_piControl_r1i1p1_185001-191912.nc',
                      }   
fluxPaths_PI['hg'] = {'hfls': folder+'hfls_Amon_HadGEM2-ES_piControl_r1i1p1_185912-190911.nc', 
                      'hfss': folder+'hfss_Amon_HadGEM2-ES_piControl_r1i1p1_185912-190911.nc',  
                      'rlds': folder+'rlds_Amon_HadGEM2-ES_piControl_r1i1p1_185912-190911.nc', 
                      'rlus': folder+'rlus_Amon_HadGEM2-ES_piControl_r1i1p1_185912-190911.nc', 
                      'rlut': folder+'rlut_Amon_HadGEM2-ES_piControl_r1i1p1_185912-190911.nc',   
                      'rlutcs': folder+'rlutcs_Amon_HadGEM2-ES_piControl_r1i1p1_185912-190911.nc',
                      'rsds': folder+'rsds_Amon_HadGEM2-ES_piControl_r1i1p1_185912-190911.nc', 
                      'rsdt': folder+'rsdt_Amon_HadGEM2-ES_piControl_r1i1p1_185912-190911.nc', 
                      'rsus': folder+'rsus_Amon_HadGEM2-ES_piControl_r1i1p1_185912-190911.nc', 
                      'rsut': folder+'rsut_Amon_HadGEM2-ES_piControl_r1i1p1_185912-190911.nc',
                      'prsn': folder+'prsn_Amon_HadGEM2-ES_piControl_r1i1p1_185912-190911.nc',
                      }     
fluxPaths_PI['ip'] = {'hfls': folder+'hfls_Amon_IPSL-CM5A-LR_piControl_r1i1p1_237001-279912.nc', 
                      'hfss': folder+'hfss_Amon_IPSL-CM5A-LR_piControl_r1i1p1_180001-279912.nc',  
                      'rlds': folder+'rlds_Amon_IPSL-CM5A-LR_piControl_r1i1p1_180001-279912.nc', 
                      'rlus': folder+'rlus_Amon_IPSL-CM5A-LR_piControl_r1i1p1_180001-279912.nc', 
                      'rlut': folder+'rlut_Amon_IPSL-CM5A-LR_piControl_r1i1p1_180001-279912.nc',   
                      'rlutcs': folder+'rlutcs_Amon_IPSL-CM5A-LR_piControl_r1i1p1_180001-279912.nc',
                      'rsds': folder+'rsds_Amon_IPSL-CM5A-LR_piControl_r1i1p1_180001-279912.nc', 
                      'rsdt': folder+'rsdt_Amon_IPSL-CM5A-LR_piControl_r1i1p1_180001-279912.nc', 
                      'rsus': folder+'rsus_Amon_IPSL-CM5A-LR_piControl_r1i1p1_180001-279912.nc', 
                      'rsut': folder+'rsut_Amon_IPSL-CM5A-LR_piControl_r1i1p1_180001-279912.nc',
                      'prsn': folder+'prsn_Amon_IPSL-CM5A-LR_piControl_r1i1p1_180001-279912.nc',
                      }      
fluxPaths_PI['mi'] = {'hfls': folder+'hfls_Amon_MIROC-ESM_piControl_r1i1p1_180001-233012.nc', 
                      'hfss': folder+'hfss_Amon_MIROC-ESM_piControl_r1i1p1_180001-233012.nc', 
                      'rlds': folder+'rlds_Amon_MIROC-ESM_piControl_r1i1p1_180001-233012.nc',  
                      'rlus': folder+'rlus_Amon_MIROC-ESM_piControl_r1i1p1_180001-233012.nc', 
                      'rlut': folder+'rlut_Amon_MIROC-ESM_piControl_r1i1p1_180001-233012.nc', 
                      'rlutcs': folder+'rlutcs_Amon_MIROC-ESM_piControl_r1i1p1_180001-233012.nc',
                      'rsds': folder+'rsds_Amon_MIROC-ESM_piControl_r1i1p1_180001-233012.nc', 
                      'rsdt': folder+'rsdt_Amon_MIROC-ESM_piControl_r1i1p1_180001-233012.nc', 
                      'rsus': folder+'rsus_Amon_MIROC-ESM_piControl_r1i1p1_180001-233012.nc', 
                      'rsut': folder+'rsut_Amon_MIROC-ESM_piControl_r1i1p1_180001-233012.nc',
                      'prsn': folder+'prsn_Amon_MIROC-ESM_piControl_r1i1p1_180001-233012.nc',
                      }
fluxPaths_PI['mp'] = {'hfls': folder+'hfls_Amon_MPI-ESM-LR_piControl_r1i1p1_185001-203512.nc', 
                      'hfss': folder+'hfss_Amon_MPI-ESM-LR_piControl_r1i1p1_185001-203512.nc',  
                      'rlds': folder+'rlds_Amon_MPI-ESM-LR_piControl_r1i1p1_185001-203512.nc', 
                      'rlus': folder+'rlus_Amon_MPI-ESM-LR_piControl_r1i1p1_185001-203512.nc', 
                      'rlut': folder+'rlut_Amon_MPI-ESM-LR_piControl_r1i1p1_185001-203512.nc',   
                      'rlutcs': folder+'rlutcs_Amon_MPI-ESM-LR_piControl_r1i1p1_185001-203512.nc',
                      'rsds': folder+'rsds_Amon_MPI-ESM-LR_piControl_r1i1p1_185001-203512.nc', 
                      'rsdt': folder+'rsdt_Amon_MPI-ESM-LR_piControl_r1i1p1_185001-203512.nc', 
                      'rsus': folder+'rsus_Amon_MPI-ESM-LR_piControl_r1i1p1_185001-203512.nc', 
                      'rsut': folder+'rsut_Amon_MPI-ESM-LR_piControl_r1i1p1_185001-203512.nc',
                      'prsn': folder+'prsn_Amon_MPI-ESM-LR_piControl_r1i1p1_185001-203512.nc',
                      }                                            
fluxPaths_PI['no'] = {'hfls': folder+'hfls_Amon_NorESM1-M_piControl_r1i1p1_070101-115012.nc', 
                      'hfss': folder+'hfss_Amon_NorESM1-M_piControl_r1i1p1_070101-115012.nc',  
                      'rlds': folder+'rlds_Amon_NorESM1-M_piControl_r1i1p1_070101-115012.nc', 
                      'rlus': folder+'rlus_Amon_NorESM1-M_piControl_r1i1p1_070101-115012.nc', 
                      'rlut': folderNor+'rlut_Amon_NorESM1-M_piControl_r1i1p1_070101-120012.nc',  
                      'rlutcs': folder+'rlutcs_Amon_NorESM1-M_piControl_r1i1p1_070001-115012.nc',
                      'rsds': folder+'rsds_Amon_NorESM1-M_piControl_r1i1p1_070101-115012.nc', 
                      'rsdt': folder+'rsdt_Amon_NorESM1-M_piControl_r1i1p1_070101-115012.nc', 
                      'rsus': folder+'rsus_Amon_NorESM1-M_piControl_r1i1p1_070101-115012.nc', 
                      'rsut': folder+'rsut_Amon_NorESM1-M_piControl_r1i1p1_070101-115012.nc',
                      'prsn': folder+'prsn_Amon_NorESM1-M_piControl_r1i1p1_070101-115012.nc',
                      }    
                      

fluxPaths_G1 = OrderedDict()
fluxPaths_G1['ca'] = {'rsdt': folder+'rsdt_Amon_CanESM2_G1_r1i1p1_185001-194912.nc',
                      'rsut': folder+'rsut_Amon_CanESM2_G1_r1i1p1_185001-194912.nc',
                      'rlut': folder+'rlut_Amon_CanESM2_G1_r1i1p1_185001-194912.nc',
                      'rlutcs': folder+'rlutcs_Amon_CanESM2_G1_r1i1p1_185001-194912.nc',
                      'rsds': folder+'rsds_Amon_CanESM2_G1_r1i1p1_185001-194912.nc',
                      'rlds': folder+'rlds_Amon_CanESM2_G1_r1i1p1_185001-194912.nc',
                      'rsus': folder+'rsus_Amon_CanESM2_G1_r1i1p1_185001-194912.nc', 
                      'rlus': folder+'rlus_Amon_CanESM2_G1_r1i1p1_185001-194912.nc',
                      'hfls': folder+'hfls_Amon_CanESM2_G1_r1i1p1_185001-194912.nc',
                      'hfss': folder+'hfss_Amon_CanESM2_G1_r1i1p1_185001-194912.nc',
                      'prsn': folder+'prsn_Amon_CanESM2_G1_r1i1p1_185001-194912.nc',
                      }
fluxPaths_G1['cc'] = {'rsdt': folder+'rsdt_Amon_CCSM4_G1_r1i1p1_185001-192412.nc',
                      'rsut': folder+'rsut_Amon_CCSM4_G1_r1i1p1_185001-192412.nc',
                      'rlut': folderCCSM+'rlut_Amon_CCSM4_G1_r1i1p1_185001-192412.nc',
                      'rlutcs': folderCCSM+'rlutcs_Amon_CCSM4_G1_r1i1p1_185001-192412.nc',
                      'rsds': folder+'rsds_Amon_CCSM4_G1_r1i1p1_185001-192412.nc',
                      'rlds': folder+'rlds_Amon_CCSM4_G1_r1i1p1_185001-192412.nc', 
                      'rsus': folder+'rsus_Amon_CCSM4_G1_r1i1p1_185001-192412.nc',
                      'rlus': folder+'rlus_Amon_CCSM4_G1_r1i1p1_185001-192412.nc',
                      'hfls': folder+'hfls_Amon_CCSM4_G1_r1i1p1_185001-192412.nc',
                      'hfss': folder+'hfss_Amon_CCSM4_G1_r1i1p1_185001-192412.nc',
                      'prsn': folder+'prsn_Amon_CCSM4_G1_r1i1p1_185001-192412.nc',
                      }
fluxPaths_G1['ce'] = {'rsdt': folder+'rsdt_Amon_CESM1-CAM5-1-FV2_G1_r1i1p1_000101-006001.nc',
                      'rsut': folder+'rsut_Amon_CESM1-CAM5-1-FV2_G1_r1i1p1_000101-006001.nc',
                      'rlut': folderCESM+'rlut_Amon_CESM1-CAM5.1-FV2_G1_r1i1p1_000101-006012.nc', 
                      'rlutcs': folder+'rlutcs_Amon_CESM1-CAM5-1-FV2_G1_r1i1p1_000101-006001.nc', 
                      'rsds': folder+'rsds_Amon_CESM1-CAM5-1-FV2_G1_r1i1p1_000101-005912.nc',
                      'rlds': folder+'rlds_Amon_CESM1-CAM5-1-FV2_G1_r1i1p1_000101-005912.nc',
                      'rsus': folder+'rsus_Amon_CESM1-CAM5-1-FV2_G1_r1i1p1_000101-005912.nc',
                      'rlus': folder+'rlus_Amon_CESM1-CAM5-1-FV2_G1_r1i1p1_000101-005912.nc',
                      'hfls': folder+'hfls_Amon_CESM1-CAM5-1-FV2_G1_r1i1p1_000101-006001.nc',
                      'hfss': folder+'hfss_Amon_CESM1-CAM5-1-FV2_G1_r1i1p1_000101-005912.nc',
                      'prsn': folder+'prsn_Amon_CESM1-CAM5-1-FV2_G1_r1i1p1_000101-006001.nc',
                      }                               
fluxPaths_G1['gi'] = {'hfls': folder+'hfls_Amon_GISS-E2-R_G1_r1i1p1_185001-191912.nc', 
                      'hfss': folder+'hfss_Amon_GISS-E2-R_G1_r1i1p1_185001-191912.nc',  
                      'rlds': folder+'rlds_Amon_GISS-E2-R_G1_r1i1p1_185001-191912.nc', 
                      'rlus': folder+'rlus_Amon_GISS-E2-R_G1_r1i1p1_185001-191912.nc', 
                      'rlut': folder+'rlut_Amon_GISS-E2-R_G1_r1i1p1_185001-191912.nc',   
                      'rlutcs': folder+'rlutcs_Amon_GISS-E2-R_G1_r1i1p1_185001-191912.nc',
                      'rsds': folder+'rsds_Amon_GISS-E2-R_G1_r1i1p1_185001-191912.nc', 
                      'rsdt': folder+'rsdt_Amon_GISS-E2-R_G1_r1i1p1_185001-191912.nc', 
                      'rsus': folder+'rsus_Amon_GISS-E2-R_G1_r1i1p1_185001-191912.nc', 
                      'rsut': folder+'rsut_Amon_GISS-E2-R_G1_r1i1p1_185001-191912.nc',
                      'prsn': folder+'prsn_Amon_GISS-E2-R_G1_r1i1p1_185001-191912.nc',
                      }                    
fluxPaths_G1['hg'] = {'hfls': folder+'hfls_Amon_HadGEM2-ES_G1_r1i1p1_185912-190911.nc', 
                      'hfss': folder+'hfss_Amon_HadGEM2-ES_G1_r1i1p1_185912-190911.nc',  
                      'rlds': folder+'rlds_Amon_HadGEM2-ES_G1_r1i1p1_185912-190911.nc', 
                      'rlus': folder+'rlus_Amon_HadGEM2-ES_G1_r1i1p1_185912-190911.nc', 
                      'rlut': folder+'rlut_Amon_HadGEM2-ES_G1_r1i1p1_185912-190911.nc',   
                      'rlutcs': folder+'rlutcs_Amon_HadGEM2-ES_G1_r1i1p1_185912-190911.nc',
                      'rsds': folder+'rsds_Amon_HadGEM2-ES_G1_r1i1p1_185912-190911.nc', 
                      'rsdt': folder+'rsdt_Amon_HadGEM2-ES_G1_r1i1p1_185912-190911.nc', 
                      'rsus': folder+'rsus_Amon_HadGEM2-ES_G1_r1i1p1_185912-190911.nc', 
                      'rsut': folder+'rsut_Amon_HadGEM2-ES_G1_r1i1p1_185912-190911.nc',
                      'prsn': folder+'prsn_Amon_HadGEM2-ES_G1_r1i1p1_185912-190911.nc',
                      }                      
fluxPaths_G1['ip'] = {'hfls': folder+'hfls_Amon_IPSL-CM5A-LR_G1_r1i1p1_185001-189912.nc', 
                      'hfss': folder+'hfss_Amon_IPSL-CM5A-LR_G1_r1i1p1_185001-189912.nc',  
                      'rlds': folder+'rlds_Amon_IPSL-CM5A-LR_G1_r1i1p1_185001-189912.nc', 
                      'rlus': folder+'rlus_Amon_IPSL-CM5A-LR_G1_r1i1p1_185001-189912.nc', 
                      'rlut': folder+'rlut_Amon_IPSL-CM5A-LR_G1_r1i1p1_185001-189912.nc',   
                      'rlutcs': folder+'rlutcs_Amon_IPSL-CM5A-LR_G1_r1i1p1_185001-189912.nc',
                      'rsds': folder+'rsds_Amon_IPSL-CM5A-LR_G1_r1i1p1_185001-189912.nc', 
                      'rsdt': folder+'rsdt_Amon_IPSL-CM5A-LR_G1_r1i1p1_185001-189912.nc', 
                      'rsus': folder+'rsus_Amon_IPSL-CM5A-LR_G1_r1i1p1_185001-189912.nc', 
                      'rsut': folder+'rsut_Amon_IPSL-CM5A-LR_G1_r1i1p1_185001-189912.nc',
                      'prsn': folder+'prsn_Amon_IPSL-CM5A-LR_G1_r1i1p1_185001-189912.nc',
                      }                      
fluxPaths_G1['mi'] = {'hfls': folder+'hfls_Amon_MIROC-ESM_G1_r1i1p1_000101-005212.nc', 
                      'hfss': folder+'hfss_Amon_MIROC-ESM_G1_r1i1p1_000101-005212.nc',  
                      'rlds': folder+'rlds_Amon_MIROC-ESM_G1_r1i1p1_000101-005212.nc', 
                      'rlus': folder+'rlus_Amon_MIROC-ESM_G1_r1i1p1_000101-005212.nc', 
                      'rlut': folder+'rlut_Amon_MIROC-ESM_G1_r1i1p1_000101-005212.nc',   
                      'rlutcs': folder+'rlutcs_Amon_MIROC-ESM_G1_r1i1p1_000101-005212.nc',
                      'rsds': folder+'rsds_Amon_MIROC-ESM_G1_r1i1p1_000101-005212.nc', 
                      'rsdt': folder+'rsdt_Amon_MIROC-ESM_G1_r1i1p1_000101-005212.nc', 
                      'rsus': folder+'rsus_Amon_MIROC-ESM_G1_r1i1p1_000101-005212.nc', 
                      'rsut': folder+'rsut_Amon_MIROC-ESM_G1_r1i1p1_000101-005212.nc',
                      'prsn': folder+'prsn_Amon_MIROC-ESM_G1_r1i1p1_000101-005212.nc',
                      }
fluxPaths_G1['mp'] = {'hfls': folder+'hfls_Amon_MPI-ESM-LR_G1_r2i1p1_185001-191912.nc', 
                      'hfss': folder+'hfss_Amon_MPI-ESM-LR_G1_r2i1p1_185001-191912.nc',  
                      'rlds': folder+'rlds_Amon_MPI-ESM-LR_G1_r2i1p1_185001-191912.nc', 
                      'rlus': folder+'rlus_Amon_MPI-ESM-LR_G1_r2i1p1_185001-191912.nc', 
                      'rlut': folder+'rlut_Amon_MPI-ESM-LR_G1_r2i1p1_185001-189912.nc',   
                      'rlutcs': folder+'rlutcs_Amon_MPI-ESM-LR_G1_r2i1p1_185001-191912.nc',
                      'rsds': folder+'rsds_Amon_MPI-ESM-LR_G1_r2i1p1_185001-191912.nc', 
                      'rsdt': folder+'rsdt_Amon_MPI-ESM-LR_G1_r2i1p1_185001-189912.nc', 
                      'rsus': folder+'rsus_Amon_MPI-ESM-LR_G1_r2i1p1_185001-191912.nc', 
                      'rsut': folder+'rsut_Amon_MPI-ESM-LR_G1_r2i1p1_185001-189912.nc',
                      'prsn': folder+'prsn_Amon_MPI-ESM-LR_G1_r2i1p1_185001-191912.nc', 
                      }                      
fluxPaths_G1['no'] = {'hfls': folder+'hfls_Amon_NorESM1-M_G1_r1i1p1_000101-005012.nc', 
                      'hfss': folder+'hfss_Amon_NorESM1-M_G1_r1i1p1_000101-005012.nc', 
                      'rlds': folder+'rlds_Amon_NorESM1-M_G1_r1i1p1_000101-005012.nc', 
                      'rlus': folder+'rlus_Amon_NorESM1-M_G1_r1i1p1_000101-005012.nc', 
                      'rlut': folderNor+'rlut_Amon_NorESM1-M_G1_r1i1p1_000101-005012.nc',   
                      'rlutcs': folder+'rlutcs_Amon_NorESM1-M_G1_r1i1p1_000101-005012.nc',
                      'rsds': folder+'rsds_Amon_NorESM1-M_G1_r1i1p1_000101-005012.nc', 
                      'rsdt': folder+'rsdt_Amon_NorESM1-M_G1_r1i1p1_000101-005012.nc', 
                      'rsus': folder+'rsus_Amon_NorESM1-M_G1_r1i1p1_000101-005012.nc', 
                      'rsut': folder+'rsut_Amon_NorESM1-M_G1_r1i1p1_000101-005012.nc',
                      'prsn': folder+'prsn_Amon_NorESM1-M_G1_r1i1p1_000101-005012.nc',
                      }                      
                      
                      
                      
                      
fluxPaths_A4 = OrderedDict()
fluxPaths_A4['ca'] = {'hfls': folder+'hfls_Amon_CanESM2_abrupt4xCO2_r1i1p1_185001-199912.nc',
                      'hfss': folder+'hfss_Amon_CanESM2_abrupt4xCO2_r1i1p1_185001-199912.nc',
                      'rlds': folder+'rlds_Amon_CanESM2_abrupt4xCO2_r1i1p1_185001-199912.nc',
                      'rlus': folder+'rlus_Amon_CanESM2_abrupt4xCO2_r1i1p1_185001-199912.nc',
                      'rlut': folder+'rlut_Amon_CanESM2_abrupt4xCO2_r1i1p1_185001-199912.nc',
                      'rlutcs': folder+'rlutcs_Amon_CanESM2_abrupt4xCO2_r1i1p1_185001-199912.nc',
                      'rsds': folder+'rsds_Amon_CanESM2_abrupt4xCO2_r1i1p1_185001-199912.nc',
                      'rsdt': folder+'rsdt_Amon_CanESM2_abrupt4xCO2_r1i1p1_185001-199912.nc',
                      'rsus': folder+'rsus_Amon_CanESM2_abrupt4xCO2_r1i1p1_185001-199912.nc',
                      'rsut': folder+'rsut_Amon_CanESM2_abrupt4xCO2_r1i1p1_185001-199912.nc',
                      'prsn': folder+'prsn_Amon_CanESM2_abrupt4xCO2_r1i1p1_185001-199912.nc',
                      }
fluxPaths_A4['cc'] = {'hfls': folder+'hfls_Amon_CCSM4_abrupt4xCO2_r1i1p1_185001-200012.nc',
                      'hfss': folder+'hfss_Amon_CCSM4_abrupt4xCO2_r1i1p1_185001-200012.nc',
                      'rlds': folder+'rlds_Amon_CCSM4_abrupt4xCO2_r1i1p1_185001-200012.nc',
                      'rlus': folder+'rlus_Amon_CCSM4_abrupt4xCO2_r1i1p1_185001-200012.nc',
                      'rlut': folderCCSM+'rlut_Amon_CCSM4_abrupt4xCO2_r1i1p1_185001-200012.nc',
                      'rlutcs': folderCCSM+'rlutcs_Amon_CCSM4_abrupt4xCO2_r1i1p1_185001-200012.nc',
                      'rsds': folder+'rsds_Amon_CCSM4_abrupt4xCO2_r1i1p1_185001-200012.nc',
                      'rsdt': folder+'rsdt_Amon_CCSM4_abrupt4xCO2_r1i1p1_185001-200012.nc',
                      'rsus': folder+'rsus_Amon_CCSM4_abrupt4xCO2_r1i1p1_185001-200012.nc',
                      'rsut': folder+'rsut_Amon_CCSM4_abrupt4xCO2_r1i1p1_185001-200012.nc',
                      'prsn': folder+'prsn_Amon_CCSM4_abrupt4xCO2_r1i1p1_185001-200012.nc',
                      }
fluxPaths_A4['ce'] = {'rsdt': folder+'rsdt_Amon_CESM1-CAM5-1-FV2_abrupt4xCO2_r3i1p1_000101-015012.nc',
                      'rsut': folder+'rsut_Amon_CESM1-CAM5-1-FV2_abrupt4xCO2_r3i1p1_000101-015012.nc',
                      'rlut': folderCESM+'rlut_Amon_CESM1-CAM5.1-FV2_abrupt4xCO2_r3i1p1_000101-015012.nc', 
                      'rlutcs': folder+'rlutcs_Amon_CESM1-CAM5-1-FV2_abrupt4xCO2_r3i1p1_000101-015012.nc', 
                      'rsds': folder+'rsds_Amon_CESM1-CAM5-1-FV2_abrupt4xCO2_r3i1p1_000101-015012.nc',
                      'rlds': folder+'rlds_Amon_CESM1-CAM5-1-FV2_abrupt4xCO2_r3i1p1_000101-015012.nc',
                      'rsus': folder+'rsus_Amon_CESM1-CAM5-1-FV2_abrupt4xCO2_r3i1p1_000101-015012.nc',
                      'rlus': folder+'rlus_Amon_CESM1-CAM5-1-FV2_abrupt4xCO2_r3i1p1_000101-015012.nc',
                      'hfls': folder+'hfls_Amon_CESM1-CAM5-1-FV2_abrupt4xCO2_r3i1p1_000101-015012.nc',
                      'hfss': folder+'hfss_Amon_CESM1-CAM5-1-FV2_abrupt4xCO2_r3i1p1_000101-015012.nc',
                      'prsn': folder+'prsn_Amon_CESM1-CAM5-1-FV2_abrupt4xCO2_r3i1p1_000101-015012.nc',
                      }                               
fluxPaths_A4['gi'] = {'hfls': folder+'hfls_Amon_GISS-E2-R_abrupt4xCO2_r1i1p1_185001-191912.nc', 
                      'hfss': folder+'hfss_Amon_GISS-E2-R_abrupt4xCO2_r1i1p1_185001-191912.nc',  
                      'rlds': folder+'rlds_Amon_GISS-E2-R_abrupt4xCO2_r1i1p1_185001-191912.nc', 
                      'rlus': folder+'rlus_Amon_GISS-E2-R_abrupt4xCO2_r1i1p1_185001-191912.nc', 
                      'rlut': folder+'rlut_Amon_GISS-E2-R_abrupt4xCO2_r1i1p1_185001-191912.nc',   
                      'rlutcs': folder+'rlutcs_Amon_GISS-E2-R_abrupt4xCO2_r1i1p1_185001-191912.nc',
                      'rsds': folder+'rsds_Amon_GISS-E2-R_abrupt4xCO2_r1i1p1_185001-191912.nc', 
                      'rsdt': folder+'rsdt_Amon_GISS-E2-R_abrupt4xCO2_r1i1p1_185001-191912.nc', 
                      'rsus': folder+'rsus_Amon_GISS-E2-R_abrupt4xCO2_r1i1p1_185001-191912.nc', 
                      'rsut': folder+'rsut_Amon_GISS-E2-R_abrupt4xCO2_r1i1p1_185001-191912.nc',
                      'prsn': folder+'prsn_Amon_GISS-E2-R_abrupt4xCO2_r1i1p1_185001-191912.nc', 
                      }   
fluxPaths_A4['hg'] = {'hfls': folder+'hfls_Amon_HadGEM2-ES_abrupt4xCO2_r1i1p1_185912-191011.nc', 
                      'hfss': folder+'hfss_Amon_HadGEM2-ES_abrupt4xCO2_r1i1p1_185912-191011.nc',  
                      'rlds': folder+'rlds_Amon_HadGEM2-ES_abrupt4xCO2_r1i1p1_185912-191011.nc', 
                      'rlus': folder+'rlus_Amon_HadGEM2-ES_abrupt4xCO2_r1i1p1_185912-191011.nc', 
                      'rlut': folder+'rlut_Amon_HadGEM2-ES_abrupt4xCO2_r1i1p1_185912-191011.nc',   
                      'rlutcs': folder+'rlutcs_Amon_HadGEM2-ES_abrupt4xCO2_r1i1p1_185912-191011.nc',
                      'rsds': folder+'rsds_Amon_HadGEM2-ES_abrupt4xCO2_r1i1p1_185912-191011.nc', 
                      'rsdt': folder+'rsdt_Amon_HadGEM2-ES_abrupt4xCO2_r1i1p1_185912-191011.nc', 
                      'rsus': folder+'rsus_Amon_HadGEM2-ES_abrupt4xCO2_r1i1p1_185912-191011.nc', 
                      'rsut': folder+'rsut_Amon_HadGEM2-ES_abrupt4xCO2_r1i1p1_185912-191011.nc',
                      'prsn': folder+'prsn_Amon_HadGEM2-ES_abrupt4xCO2_r1i1p1_185912-191011.nc',  
                      }     
fluxPaths_A4['ip'] = {'hfls': folder+'hfls_Amon_IPSL-CM5A-LR_abrupt4xCO2_r1i1p1_185001-204912.nc', 
                      'hfss': folder+'hfss_Amon_IPSL-CM5A-LR_abrupt4xCO2_r1i1p1_185001-204912.nc',  
                      'rlds': folder+'rlds_Amon_IPSL-CM5A-LR_abrupt4xCO2_r1i1p1_185001-204912.nc', 
                      'rlus': folder+'rlus_Amon_IPSL-CM5A-LR_abrupt4xCO2_r1i1p1_185001-204912.nc', 
                      'rlut': folder+'rlut_Amon_IPSL-CM5A-LR_abrupt4xCO2_r1i1p1_185001-204912.nc',  
                      'rlutcs': folder+'rlutcs_Amon_IPSL-CM5A-LR_abrupt4xCO2_r1i1p1_185001-204912.nc',
                      'rsds': folder+'rsds_Amon_IPSL-CM5A-LR_abrupt4xCO2_r1i1p1_185001-204912.nc', 
                      'rsdt': folder+'rsdt_Amon_IPSL-CM5A-LR_abrupt4xCO2_r1i1p1_185001-204912.nc', 
                      'rsus': folder+'rsus_Amon_IPSL-CM5A-LR_abrupt4xCO2_r1i1p1_185001-204912.nc', 
                      'rsut': folder+'rsut_Amon_IPSL-CM5A-LR_abrupt4xCO2_r1i1p1_185001-204912.nc',
                      'prsn': folder+'prsn_Amon_IPSL-CM5A-LR_abrupt4xCO2_r1i1p1_185001-204912.nc',  
                      }      
fluxPaths_A4['mi'] = {'hfls': folder+'hfls_Amon_MIROC-ESM_abrupt4xCO2_r1i1p1_000101-015012.nc', 
                      'hfss': folder+'hfss_Amon_MIROC-ESM_abrupt4xCO2_r1i1p1_000101-015012.nc',  
                      'rlds': folder+'rlds_Amon_MIROC-ESM_abrupt4xCO2_r1i1p1_000101-015012.nc', 
                      'rlus': folder+'rlus_Amon_MIROC-ESM_abrupt4xCO2_r1i1p1_000101-015012.nc', 
                      'rlut': folder+'rlut_Amon_MIROC-ESM_abrupt4xCO2_r1i1p1_000101-015012.nc', 
                      'rlutcs': folder+'rlutcs_Amon_MIROC-ESM_abrupt4xCO2_r1i1p1_000101-015012.nc',
                      'rsds': folder+'rsds_Amon_MIROC-ESM_abrupt4xCO2_r1i1p1_000101-015012.nc', 
                      'rsdt': folder+'rsdt_Amon_MIROC-ESM_abrupt4xCO2_r1i1p1_000101-015012.nc', 
                      'rsus': folder+'rsus_Amon_MIROC-ESM_abrupt4xCO2_r1i1p1_000101-015012.nc', 
                      'rsut': folder+'rsut_Amon_MIROC-ESM_abrupt4xCO2_r1i1p1_000101-015012.nc',
                      'prsn': folder+'prsn_Amon_MIROC-ESM_abrupt4xCO2_r1i1p1_000101-015012.nc',  
                      }
fluxPaths_A4['mp'] = {'hfls': folder+'hfls_Amon_MPI-ESM-LR_abrupt4xCO2_r1i1p1_185001-199912.nc', 
                      'hfss': folder+'hfss_Amon_MPI-ESM-LR_abrupt4xCO2_r1i1p1_185001-199912.nc',  
                      'rlds': folder+'rlds_Amon_MPI-ESM-LR_abrupt4xCO2_r1i1p1_185001-199912.nc', 
                      'rlus': folder+'rlus_Amon_MPI-ESM-LR_abrupt4xCO2_r1i1p1_185001-199912.nc', 
                      'rlut': folder+'rlut_Amon_MPI-ESM-LR_abrupt4xCO2_r1i1p1_185001-199912.nc',   
                      'rlutcs': folder+'rlutcs_Amon_MPI-ESM-LR_abrupt4xCO2_r1i1p1_185001-199912.nc',
                      'rsds': folder+'rsds_Amon_MPI-ESM-LR_abrupt4xCO2_r1i1p1_185001-199912.nc', 
                      'rsdt': folder+'rsdt_Amon_MPI-ESM-LR_abrupt4xCO2_r1i1p1_185001-199912.nc', 
                      'rsus': folder+'rsus_Amon_MPI-ESM-LR_abrupt4xCO2_r1i1p1_185001-199912.nc', 
                      'rsut': folder+'rsut_Amon_MPI-ESM-LR_abrupt4xCO2_r1i1p1_185001-199912.nc',
                      'prsn': folder+'prsn_Amon_MPI-ESM-LR_abrupt4xCO2_r1i1p1_185001-199912.nc',
                      }                                            
fluxPaths_A4['no'] = {'hfls': folder+'hfls_Amon_NorESM1-M_abrupt4xCO2_r1i1p1_000101-015012.nc', 
                      'hfss': folder+'hfss_Amon_NorESM1-M_abrupt4xCO2_r1i1p1_000101-015012.nc',  
                      'rlds': folder+'rlds_Amon_NorESM1-M_abrupt4xCO2_r1i1p1_000101-015012.nc', 
                      'rlus': folder+'rlus_Amon_NorESM1-M_abrupt4xCO2_r1i1p1_000101-015012.nc', 
                      'rlut': folderNor+'rlut_Amon_NorESM1-M_abrupt4xCO2_r1i1p1_000101-015012.nc',   
                      'rlutcs': folder+'rlutcs_Amon_NorESM1-M_abrupt4xCO2_r1i1p1_000101-015012.nc',
                      'rsds': folder+'rsds_Amon_NorESM1-M_abrupt4xCO2_r1i1p1_000101-015012.nc', 
                      'rsdt': folder+'rsdt_Amon_NorESM1-M_abrupt4xCO2_r1i1p1_000101-015012.nc', 
                      'rsus': folder+'rsus_Amon_NorESM1-M_abrupt4xCO2_r1i1p1_000101-015012.nc', 
                      'rsut': folder+'rsut_Amon_NorESM1-M_abrupt4xCO2_r1i1p1_000101-015012.nc',
                      'prsn': folder+'prsn_Amon_NorESM1-M_abrupt4xCO2_r1i1p1_000101-015012.nc',
                      }                                  
                      


#Whether to flip the sign of sensible heat flux (GISS reported with the wrong sign convention)
flipSensible = {'bn': False, 'ca': False, 'cc': False, 'ce': False, 'cs': False, 'gi': True,
                'hg': False, 'ip': False, 'mi': False, 'mp': False, 'no': False}

#Whether to flip sign of clear-sky OLR (GISS reported with the wrong sign convention)                    
flipClearSkyOLR = {'bn': False, 'ca': False, 'cc': False, 'ce': False, 'cs': False, 'gi': True,
                   'hg': False, 'ip': False, 'mi': False, 'mp': False, 'no': False}                      

#Create NetCDF4 Dataset objects in nested dictionaries using nested loops
#("key" refers to model, "innerKey" refers to variable)          
Datasets_PI = OrderedDict()
for key in fluxPaths_PI.keys():
    Datasets_PI[key] = dict()
    for innerKey in fluxPaths_PI[key].keys():
        print(key)
        Datasets_PI[key][innerKey] = nc4.Dataset(fluxPaths_PI[key][innerKey])   
        
Datasets_G1 = OrderedDict()
for key in fluxPaths_G1.keys():
    Datasets_G1[key] = dict()
    for innerKey in fluxPaths_G1[key].keys():
        Datasets_G1[key][innerKey] = nc4.Dataset(fluxPaths_G1[key][innerKey])     
        
Datasets_A4 = OrderedDict()
for key in fluxPaths_A4.keys():
    Datasets_A4[key] = dict()
    for innerKey in fluxPaths_A4[key].keys():
        Datasets_A4[key][innerKey] = nc4.Dataset(fluxPaths_A4[key][innerKey])           

#Obtain the latitudes
latDict = OrderedDict()
latDict['ca'] = Datasets_PI['ca']['rsdt'].variables['lat'][:]
latDict['cc'] = Datasets_PI['cc']['rsdt'].variables['lat'][:]
latDict['ce'] = Datasets_PI['ce']['rsdt'].variables['lat'][:]
latDict['gi'] = Datasets_PI['gi']['rsdt'].variables['lat'][:]
latDict['hg'] = Datasets_PI['hg']['rsdt'].variables['lat'][:]
latDict['ip'] = Datasets_PI['ip']['rsdt'].variables['lat'][:]
latDict['mi'] = Datasets_PI['mi']['rsdt'].variables['lat'][:]
latDict['mp'] = Datasets_PI['mp']['rsdt'].variables['lat'][:]
latDict['no'] = Datasets_PI['no']['rsdt'].variables['lat'][:]   

#Obtain the boundary latitudes
lat_bndsDict = OrderedDict()
for key in latDict.keys():
    temp = Datasets_G1[key]['rsdt'].variables['lat_bnds'][:,0]
    lat_bndsDict[key] = np.append(temp, Datasets_G1[key]['rsdt'].variables['lat_bnds'][-1,-1])


# Load the APRP results--necessary for running the EBM for the perturabtion climate
# Save in a dictionary--loop over this dictionary's keys when I run the EBM the 2nd time 
# (because some models I don't have APRP results for). 
APRP_G1minusPI = OrderedDict()
APRP_G1minusPI['ca'] = np.load('../nobackup/npyFiles/aprp_geo_ca.npy').item()
APRP_G1minusPI['cc'] = np.load('../nobackup/npyFiles/aprp_geo_cc.npy').item()
APRP_G1minusPI['ce'] = np.load('../nobackup/npyFiles/aprp_geo_ce.npy').item()
#APRP_G1minusPI['gi'] = np.load('../nobackup/npyFiles/aprp_geo_gi.npy').item() #Skip GISS until weird rsuscs issue resolved
APRP_G1minusPI['hg'] = np.load('../nobackup/npyFiles/aprp_geo_hg.npy').item()
APRP_G1minusPI['ip'] = np.load('../nobackup/npyFiles/aprp_geo_ip.npy').item()
APRP_G1minusPI['mi'] = np.load('../nobackup/npyFiles/aprp_geo_mi.npy').item()
APRP_G1minusPI['mp'] = np.load('../nobackup/npyFiles/aprp_geo_mp.npy').item()
APRP_G1minusPI['no'] = np.load('../nobackup/npyFiles/aprp_geo_no.npy').item()

APRP_A4minusPI = OrderedDict()
APRP_A4minusPI['ca'] = np.load('../nobackup/npyFiles/aprp_warm_ca.npy').item()
APRP_A4minusPI['cc'] = np.load('../nobackup/npyFiles/aprp_warm_cc.npy').item()
APRP_A4minusPI['ce'] = np.load('../nobackup/npyFiles/aprp_warm_ce.npy').item()
#APRP_A4minusPI['gi'] = np.load('../nobackup/npyFiles/aprp_warm_gi.npy').item() #Skip GISS until weird rsuscs issue resolved
APRP_A4minusPI['hg'] = np.load('../nobackup/npyFiles/aprp_warm_hg.npy').item()
APRP_A4minusPI['ip'] = np.load('../nobackup/npyFiles/aprp_warm_ip.npy').item()
APRP_A4minusPI['mi'] = np.load('../nobackup/npyFiles/aprp_warm_mi.npy').item()
APRP_A4minusPI['mp'] = np.load('../nobackup/npyFiles/aprp_warm_mp.npy').item()
APRP_A4minusPI['no'] = np.load('../nobackup/npyFiles/aprp_warm_no.npy').item()


#Calendar and leap years 

#Calendar types for the differnt models
calendars = {'ca': '365', 
             'cc': '365', 
             'ce': '365', 
             'cs': '365', 
             'gi': '365', 
             'hg': '360',
             'ip': '365', 
             'mi': 'Gregorian', 
             'mp': 'Gregorian', 
             'no': '365'}
             
#Array of leap years for Gregorian calendar models based on start date (here assume first year in dataset is year 0)
#For piControl: which years are leap years between 0 and 39             
leapYears_PI = {'ca': 'none', 
                'cc': 'none', 
                'ce': 'none',
                'cs': 'none', 
                'gi': 'none', 
                'hg': 'none', 
                'ip': 'none',
                'mi': np.array([4,8,12,16,20,24,28,32,36]), #Starts in 1800 which was NOT a leap year
                'mp': np.array([2,6,10,14,18,22,26,30,34,38]), #Starts in 1850
                'no': 'none'}

#For G1: which years are leap years between 10 and 49
leapYears_G1 = {'ca': 'none', 
                'cc': 'none', 
                'ce': 'none',
                'cs': 'none', 
                'gi': 'none', 
                'hg': 'none', 
                'ip': 'none',
                'mi': np.array([1,5,9,13,17,21,25,29,33,37]), #Starts in 0001 so need leap years from 11 (index 0) to 50
                'mp': np.array([0,4,8,12,16,20,24,28,32,36]), #Starts in 1850 so need leap years from 1860 (index 0) to 1899
                'no': 'none'}                

#For abrupt4xCO2: same as G1 (same start dates for MIROC and MPI)
leapYears_A4 = dict(leapYears_G1) 


#rlutcs corrections

#Load the correction for rlutcs for top of atmosphere/ top of model issue (saved by find_rlut_correction.py)
correction_PI = np.load('npyFiles/rlut_correction_PI.npy').item()
correction_G1 = np.load('npyFiles/rlut_correction_G1.npy').item()
correction_A4 = np.load('npyFiles/rlut_correction_A4.npy').item()

#This was for cc, ce, no models. Add 'none' for other models so that the functions will work. 
correction_PI['ca'] = 'none'
correction_PI['gi'] = 'none'
correction_PI['hg'] = 'none'
correction_PI['ip'] = 'none'
correction_PI['mi'] = 'none'
correction_PI['mp'] = 'none'

correction_G1['ca'] = 'none'
correction_G1['gi'] = 'none'
correction_G1['hg'] = 'none'
correction_G1['ip'] = 'none'
correction_G1['mi'] = 'none'
correction_G1['mp'] = 'none'

correction_A4['ca'] = 'none'
correction_A4['gi'] = 'none'
correction_A4['hg'] = 'none'
correction_A4['ip'] = 'none'
correction_A4['mi'] = 'none'
correction_A4['mp'] = 'none'




#####   CALCULATE ENERGY INPUT TERMS FOR EBM   #####




#Get the energy input term for running the EBM: control climate       
EI_PI = OrderedDict()
i = 0
for key, value in Datasets_PI.items():
    print('Calculating or loading energy input term (PI) for model: ' + gmf.modelNames[key])
    if not(loadFromFile_EI_PI[key]):
        EI_PI[key] = ebm.calcEI_control(Datasets_PI[key], 0, 39, flipSensible[key], flipClearSkyOLR[key], 
                                        calendar=calendars[key], leapYears=leapYears_PI[key], 
                                        rlutcsCorrection=correction_PI[key])
        #np.save('npyFiles/EBM_energyInputTerm_PI_' + key + '.npy', EI_PI[key])
        EI_PI[key].dump('npyFiles/EBM_energyInputTerm_PI_' + key + '.npy')
    else:
        EI_PI[key] = np.load('npyFiles/EBM_energyInputTerm_PI_' + key + '.npy')
    #plt.figure(i) #Debug: plot
    #plt.plot(latDict[key], EI_PI[key])
    i = i+1
    
#Get the energy input term for running the EBM: perturabtion climates (full--not one at a time analysis)
EI_G1 = OrderedDict()
i = 0
for key in loadFromFile_EI_G1.keys():
    print('Calculating or loading energy input term (G1) for model: ' + gmf.modelNames[key])
    if not(loadFromFile_EI_G1[key]):
        EI_G1[key] = ebm.calcEI_perturb(EI_PI[key], Datasets_PI[key], Datasets_G1[key], APRP_G1minusPI[key], 
                                        0, 39, 10, 49, flipSensible[key], flipClearSkyOLR[key], 
                                        calendar=calendars[key], leapYears = leapYears_G1[key], 
                                        rlutcsCorrectionOld = correction_PI[key], rlutcsCorrectionNew = correction_G1[key])
        EI_G1[key].dump('npyFiles/EBM_energyInputTerm_G1_'+key+'.npy')  #Some masked arrays so use "dump" instead of "save"
    else:
        EI_G1[key] = np.load('npyFiles/EBM_energyInputTerm_G1_' + key + '.npy')
    #plt.figure(i) #Debug: plot
    #plt.plot(latDict[key], EI_G1[key])
    i = i+1
    
EI_A4 = OrderedDict()
i = 0
for key in loadFromFile_EI_A4.keys():
    print('Calculating or loading energy input term (A4) for model: ' + gmf.modelNames[key])
    if not(loadFromFile_EI_A4[key]):
        EI_A4[key] = ebm.calcEI_perturb(EI_PI[key], Datasets_PI[key], Datasets_A4[key], APRP_A4minusPI[key], 
                                        0, 39, 10, 49, flipSensible[key], flipClearSkyOLR[key],
                                        calendar=calendars[key], leapYears = leapYears_A4[key], 
                                        rlutcsCorrectionOld = correction_PI[key], rlutcsCorrectionNew = correction_A4[key])
        EI_A4[key].dump('npyFiles/EBM_energyInputTerm_A4_'+key+'.npy')  
    else:
        EI_A4[key] = np.load('npyFiles/EBM_energyInputTerm_A4_' + key + '.npy')
    #plt.figure(i) #Debug: plot
    #plt.plot(latDict[key], EI_A4[key])
    i = i+1    
    
    
    
#Calculate the energy input term for running the EBM: experiments with individual forcings/feedbacks
EI_APRPcloud_G1 = OrderedDict()
for key in loadFromFile_EI_G1.keys():
    print('Calculating or loading energy input term (G1--APRPcloud) for model: ' + gmf.modelNames[key])
    if not(loadFromFile_EI_APRPcloud_G1[key]):
        EI_APRPcloud_G1[key] = ebm.calcEI_APRPcloud(EI_PI[key], APRP_G1minusPI[key], calendar=calendars[key])
        EI_APRPcloud_G1[key].dump('npyFiles/EBM_EI_APRPcloud_G1_'+key+'.npy') 
    else:
        EI_APRPcloud_G1[key] = np.load('npyFiles/EBM_EI_APRPcloud_G1_' + key + '.npy')

EI_APRPnoncloud_G1 = OrderedDict()
for key in loadFromFile_EI_G1.keys():
    print('Calculating or loading energy input term (G1--APRPnoncloud) for model: ' + gmf.modelNames[key])
    if not(loadFromFile_EI_APRPnoncloud_G1[key]):
        EI_APRPnoncloud_G1[key] = ebm.calcEI_APRPnoncloud(EI_PI[key], APRP_G1minusPI[key], calendar=calendars[key])
        EI_APRPnoncloud_G1[key].dump('npyFiles/EBM_EI_APRPnoncloud_G1_'+key+'.npy')  
    else:
        EI_APRPnoncloud_G1[key] = np.load('npyFiles/EBM_EI_APRPnoncloud_G1_' + key + '.npy')

EI_APRPsurface_G1 = OrderedDict()
for key in loadFromFile_EI_G1.keys():
    print('Calculating or loading energy input term (G1--APRPsurface) for model: ' + gmf.modelNames[key])
    if not(loadFromFile_EI_APRPsurface_G1[key]):
        EI_APRPsurface_G1[key] = ebm.calcEI_APRPsurface(EI_PI[key], APRP_G1minusPI[key], calendar=calendars[key])
        EI_APRPsurface_G1[key].dump('npyFiles/EBM_EI_APRPsurface_G1_'+key+'.npy')  
    else:
        EI_APRPsurface_G1[key] = np.load('npyFiles/EBM_EI_APRPsurface_G1_' + key + '.npy')

EI_solarForcing_G1 = OrderedDict()
for key in loadFromFile_EI_G1.keys():
    print('Calculating or loading energy input term (G1--solarForcing) for model: ' + gmf.modelNames[key])
    if not(loadFromFile_EI_solarForcing_G1[key]):
        EI_solarForcing_G1[key] = ebm.calcEI_solarForcing(EI_PI[key], Datasets_PI[key], Datasets_G1[key], APRP_G1minusPI[key], 
                                        0, 39, 10, 49, flipSensible[key], flipClearSkyOLR[key], 
                                        calendar=calendars[key], leapYears = leapYears_G1[key])
        EI_solarForcing_G1[key].dump('npyFiles/EBM_EI_solarForcing_G1_'+key+'.npy')  
    else:
        EI_solarForcing_G1[key] = np.load('npyFiles/EBM_EI_solarForcing_G1_' + key + '.npy')

EI_surfaceFlux_G1 = OrderedDict()
for key in loadFromFile_EI_G1.keys():
    print('Calculating or loading energy input term (G1--surfaceFlux) for model: ' + gmf.modelNames[key])
    if not(loadFromFile_EI_surfaceFlux_G1[key]):
        EI_surfaceFlux_G1[key] = ebm.calcEI_surfaceFlux(EI_PI[key], Datasets_PI[key], Datasets_G1[key],
                                        0, 39, 10, 49, flipSensible[key], 
                                        calendar=calendars[key], leapYears = leapYears_G1[key])
        EI_surfaceFlux_G1[key].dump('npyFiles/EBM_EI_surfaceFlux_G1_'+key+'.npy')  
    else:
        EI_surfaceFlux_G1[key] = np.load('npyFiles/EBM_EI_surfaceFlux_G1_' + key + '.npy')

EI_LWCRE_G1 = OrderedDict()
for key in loadFromFile_EI_G1.keys():
    print('Calculating or loading energy input term (G1--LWCRE) for model: ' + gmf.modelNames[key])
    if not(loadFromFile_EI_LWCRE_G1[key]):
        EI_LWCRE_G1[key] = ebm.calcEI_LWCRE(EI_PI[key], Datasets_PI[key], Datasets_G1[key],
                                        0, 39, 10, 49, flipClearSkyOLR[key], 
                                        calendar=calendars[key], leapYears = leapYears_G1[key], 
                                        rlutcsCorrectionOld = correction_PI[key], rlutcsCorrectionNew = correction_G1[key])
        EI_LWCRE_G1[key].dump('npyFiles/EBM_EI_LWCRE_G1_'+key+'.npy')  
    else:
        EI_LWCRE_G1[key] = np.load('npyFiles/EBM_EI_LWCRE_G1_' + key + '.npy')

#Abrupt4xCO2 versions
EI_APRPcloud_A4 = OrderedDict()
for key in loadFromFile_EI_A4.keys():
    print('Calculating or loading energy input term (A4--APRPcloud) for model: ' + gmf.modelNames[key])
    if not(loadFromFile_EI_APRPcloud_A4[key]):
        EI_APRPcloud_A4[key] = ebm.calcEI_APRPcloud(EI_PI[key], APRP_A4minusPI[key], calendar=calendars[key])
        EI_APRPcloud_A4[key].dump('npyFiles/EBM_EI_APRPcloud_A4_'+key+'.npy') 
    else:
        EI_APRPcloud_A4[key] = np.load('npyFiles/EBM_EI_APRPcloud_A4_' + key + '.npy')

EI_APRPnoncloud_A4 = OrderedDict()
for key in loadFromFile_EI_A4.keys():
    print('Calculating or loading energy input term (A4--APRPnoncloud) for model: ' + gmf.modelNames[key])
    if not(loadFromFile_EI_APRPnoncloud_A4[key]):
        EI_APRPnoncloud_A4[key] = ebm.calcEI_APRPnoncloud(EI_PI[key], APRP_A4minusPI[key], calendar=calendars[key])
        EI_APRPnoncloud_A4[key].dump('npyFiles/EBM_EI_APRPnoncloud_A4_'+key+'.npy')  
    else:
        EI_APRPnoncloud_A4[key] = np.load('npyFiles/EBM_EI_APRPnoncloud_A4_' + key + '.npy')

EI_APRPsurface_A4 = OrderedDict()
for key in loadFromFile_EI_A4.keys():
    print('Calculating or loading energy input term (A4--APRPsurface) for model: ' + gmf.modelNames[key])
    if not(loadFromFile_EI_APRPsurface_A4[key]):
        EI_APRPsurface_A4[key] = ebm.calcEI_APRPsurface(EI_PI[key], APRP_A4minusPI[key], calendar=calendars[key])
        EI_APRPsurface_A4[key].dump('npyFiles/EBM_EI_APRPsurface_A4_'+key+'.npy')  
    else:
        EI_APRPsurface_A4[key] = np.load('npyFiles/EBM_EI_APRPsurface_A4_' + key + '.npy')

EI_solarForcing_A4 = OrderedDict()
for key in loadFromFile_EI_A4.keys():
    print('Calculating or loading energy input term (A4--solarForcing) for model: ' + gmf.modelNames[key])
    if not(loadFromFile_EI_solarForcing_A4[key]):
        EI_solarForcing_A4[key] = ebm.calcEI_solarForcing(EI_PI[key], Datasets_PI[key], Datasets_A4[key], APRP_A4minusPI[key], 
                                        0, 39, 10, 49, flipSensible[key], flipClearSkyOLR[key],
                                        calendar=calendars[key], leapYears = leapYears_A4[key])
        EI_solarForcing_A4[key].dump('npyFiles/EBM_EI_solarForcing_A4_'+key+'.npy')  
    else:
        EI_solarForcing_A4[key] = np.load('npyFiles/EBM_EI_solarForcing_A4_' + key + '.npy')

EI_surfaceFlux_A4 = OrderedDict()
for key in loadFromFile_EI_A4.keys():
    print('Calculating or loading energy input term (A4--surfaceFlux) for model: ' + gmf.modelNames[key])
    if not(loadFromFile_EI_surfaceFlux_A4[key]):
        EI_surfaceFlux_A4[key] = ebm.calcEI_surfaceFlux(EI_PI[key], Datasets_PI[key], Datasets_A4[key],
                                        0, 39, 10, 49, flipSensible[key],
                                        calendar=calendars[key], leapYears = leapYears_A4[key])
        EI_surfaceFlux_A4[key].dump('npyFiles/EBM_EI_surfaceFlux_A4_'+key+'.npy')  
    else:
        EI_surfaceFlux_A4[key] = np.load('npyFiles/EBM_EI_surfaceFlux_A4_' + key + '.npy')

EI_LWCRE_A4 = OrderedDict()
for key in loadFromFile_EI_A4.keys():
    print('Calculating or loading energy input term (A4--LWCRE) for model: ' + gmf.modelNames[key])
    if not(loadFromFile_EI_LWCRE_A4[key]):
        EI_LWCRE_A4[key] = ebm.calcEI_LWCRE(EI_PI[key], Datasets_PI[key], Datasets_A4[key],
                                        0, 39, 10, 49, flipClearSkyOLR[key],
                                        calendar=calendars[key], leapYears = leapYears_A4[key], 
                                        rlutcsCorrectionOld = correction_PI[key], rlutcsCorrectionNew = correction_A4[key])
        EI_LWCRE_A4[key].dump('npyFiles/EBM_EI_LWCRE_A4_'+key+'.npy')  
    else:
        EI_LWCRE_A4[key] = np.load('npyFiles/EBM_EI_LWCRE_A4_' + key + '.npy')



#Get rid of any grid boxes at the poles before running EBM
latDictOrig = OrderedDict() #Dictionary where we don't get rid of the pole values (for use with GCM results later)
lat_bndsDictOrig = OrderedDict() #Equivalent for the boundary latitudes
for key in latDict.keys():
    EI_PI[key] = EI_PI[key][np.abs(latDict[key]) < 90.]
    if key in EI_G1.keys():
        EI_G1[key] = EI_G1[key][np.abs(latDict[key]) < 90.]
    if key in EI_A4.keys():
        EI_A4[key] = EI_A4[key][np.abs(latDict[key]) < 90.]
    if key in EI_APRPcloud_G1.keys():
        EI_APRPcloud_G1[key] = EI_APRPcloud_G1[key][np.abs(latDict[key]) < 90.]        
    if key in EI_APRPnoncloud_G1.keys():
        EI_APRPnoncloud_G1[key] = EI_APRPnoncloud_G1[key][np.abs(latDict[key]) < 90.]      
    if key in EI_APRPsurface_G1.keys():
        EI_APRPsurface_G1[key] = EI_APRPsurface_G1[key][np.abs(latDict[key]) < 90.]      
    if key in EI_solarForcing_G1.keys():
        EI_solarForcing_G1[key] = EI_solarForcing_G1[key][np.abs(latDict[key]) < 90.]      
    if key in EI_surfaceFlux_G1.keys():
        EI_surfaceFlux_G1[key] = EI_surfaceFlux_G1[key][np.abs(latDict[key]) < 90.]      
    if key in EI_LWCRE_G1.keys():
        EI_LWCRE_G1[key] = EI_LWCRE_G1[key][np.abs(latDict[key]) < 90.]              
    if key in EI_APRPcloud_A4.keys():
        EI_APRPcloud_A4[key] = EI_APRPcloud_A4[key][np.abs(latDict[key]) < 90.]        
    if key in EI_APRPnoncloud_A4.keys():
        EI_APRPnoncloud_A4[key] = EI_APRPnoncloud_A4[key][np.abs(latDict[key]) < 90.]      
    if key in EI_APRPsurface_A4.keys():
        EI_APRPsurface_A4[key] = EI_APRPsurface_A4[key][np.abs(latDict[key]) < 90.]      
    if key in EI_solarForcing_A4.keys():
        EI_solarForcing_A4[key] = EI_solarForcing_A4[key][np.abs(latDict[key]) < 90.]      
    if key in EI_surfaceFlux_A4.keys():
        EI_surfaceFlux_A4[key] = EI_surfaceFlux_A4[key][np.abs(latDict[key]) < 90.]      
    if key in EI_LWCRE_A4.keys():
        EI_LWCRE_A4[key] = EI_LWCRE_A4[key][np.abs(latDict[key]) < 90.]               
    latDictOrig[key] = latDict[key]
    latDict[key] = latDict[key][np.abs(latDict[key]) < 90.]
    lat_bndsDictOrig[key] = lat_bndsDict[key]
    if len(latDict[key]) < len(latDictOrig[key]): #Subsetted the latitudes, so subset the boundaries as well. 
        lat_bndsDict[key] = lat_bndsDict[key][1:-1] #This indexing keeps everything except the 2 endpoints. 
    
        
#Load the a and b coefficients, which were calculated in "EBM_tuneAB.py" script
dict_a = np.load('npyFiles/EBM_input_a_piControl.npy').item()
dict_b = np.load('npyFiles/EBM_input_b_piControl.npy').item()
dict_bPrime_G1 = np.load('npyFiles/EBM_input_bPrime_G1.npy').item()
dict_bPrime_A4 = np.load('npyFiles/EBM_input_bPrime_A4.npy').item()




#####   RUN EBM EXPERIMENTS   #####


        
# OK, now run the model using the a and b coefficients fit individually for each model. 


#Run the EBM for each model (control)
results_PI = OrderedDict()
for key in EI_PI.keys():
    if not(loadFromFile_results_PI[key]):   
        print('Running EBM based on output from GCM: ' + gmf.modelNames[key])
        results_PI[key] = ebm.moistEBM_main(dict_a[key], dict_b[key], EI_PI[key], latDict[key], lat_bndsDict[key], nmax=100000)
        np.save('npyFiles/EBM_results_PI_' + key + '.npy', results_PI[key])
    else:
        print('Loading EBM results: ' + gmf.modelNames[key])
        results_PI[key] = np.load('npyFiles/EBM_results_PI_' + key + '.npy').item() 

#Run the EBM for the G1 case
results_G1 = OrderedDict()
for key in EI_G1.keys():
    if not(loadFromFile_results_G1[key]):   
        print('Running EBM based on output from GCM (G1): ' + gmf.modelNames[key])
        results_G1[key] = ebm.moistEBM_main(dict_a[key], dict_bPrime_G1[key], EI_G1[key], latDict[key], lat_bndsDict[key], nmax=100000)
        np.save('npyFiles/EBM_results_G1_' + key + '.npy', results_G1[key])
    else:
        print('Loading EBM results (G1): ' + gmf.modelNames[key])
        results_G1[key] = np.load('npyFiles/EBM_results_G1_' + key + '.npy').item() 

#Run the EBM for the abrupt4xCO2 case
results_A4 = OrderedDict()
for key in EI_A4.keys():
    if not(loadFromFile_results_A4[key]):   
        print('Running EBM based on output from GCM (A4): ' + gmf.modelNames[key])
        results_A4[key] = ebm.moistEBM_main(dict_a[key], dict_bPrime_A4[key], EI_A4[key], latDict[key], lat_bndsDict[key], nmax=100000)
        np.save('npyFiles/EBM_results_A4_' + key + '.npy', results_A4[key])
    else:
        print('Loading EBM results (A4): ' + gmf.modelNames[key])
        results_A4[key] = np.load('npyFiles/EBM_results_A4_' + key + '.npy').item() 
        
        
        
#Run the EBM in each of the 7 experiments, for both G1 and abrupt4xCO2 as perturbation climates. 
results_APRPcloud_G1 = OrderedDict()
for key in EI_APRPcloud_G1.keys():
    if not(loadFromFile_results_APRPcloud_G1[key]):
        print('Running EBM based on output from GCM (APRPcloud experiment, G1): ' + gmf.modelNames[key])
        results_APRPcloud_G1[key] = ebm.moistEBM_main(dict_a[key], dict_b[key], EI_APRPcloud_G1[key], latDict[key], lat_bndsDict[key], nmax=100000)
        np.save('npyFiles/EBM_results_APRPcloud_G1_' + key + '.npy', results_APRPcloud_G1[key])
    else:
        print('Loading EBM results (APRPcloud experiment, G1): ' + gmf.modelNames[key])
        results_APRPcloud_G1[key] = np.load('npyFiles/EBM_results_APRPcloud_G1_' + key + '.npy').item()
        
results_APRPnoncloud_G1 = OrderedDict()
for key in EI_APRPnoncloud_G1.keys():
    if not(loadFromFile_results_APRPnoncloud_G1[key]):
        print('Running EBM based on output from GCM (APRPnoncloud experiment, G1): ' + gmf.modelNames[key])
        results_APRPnoncloud_G1[key] = ebm.moistEBM_main(dict_a[key], dict_b[key], EI_APRPnoncloud_G1[key], latDict[key], lat_bndsDict[key], nmax=100000)
        np.save('npyFiles/EBM_results_APRPnoncloud_G1_' + key + '.npy', results_APRPnoncloud_G1[key])
    else:
        print('Loading EBM results (APRPnoncloud experiment, G1): ' + gmf.modelNames[key])
        results_APRPnoncloud_G1[key] = np.load('npyFiles/EBM_results_APRPnoncloud_G1_' + key + '.npy').item()

results_APRPsurface_G1 = OrderedDict()
for key in EI_APRPsurface_G1.keys():
    if not(loadFromFile_results_APRPsurface_G1[key]):
        print('Running EBM based on output from GCM (APRPsurface experiment, G1): ' + gmf.modelNames[key])
        results_APRPsurface_G1[key] = ebm.moistEBM_main(dict_a[key], dict_b[key], EI_APRPsurface_G1[key], latDict[key], lat_bndsDict[key], nmax=100000)
        np.save('npyFiles/EBM_results_APRPsurface_G1_' + key + '.npy', results_APRPsurface_G1[key])
    else:
        print('Loading EBM results (APRPsurface experiment, G1): ' + gmf.modelNames[key])
        results_APRPsurface_G1[key] = np.load('npyFiles/EBM_results_APRPsurface_G1_' + key + '.npy').item()

results_solarForcing_G1 = OrderedDict()
for key in EI_solarForcing_G1.keys():
    if not(loadFromFile_results_solarForcing_G1[key]):
        print('Running EBM based on output from GCM (solarForcing experiment, G1): ' + gmf.modelNames[key])
        results_solarForcing_G1[key] = ebm.moistEBM_main(dict_a[key], dict_b[key], EI_solarForcing_G1[key], latDict[key], lat_bndsDict[key], nmax=100000)
        np.save('npyFiles/EBM_results_solarForcing_G1_' + key + '.npy', results_solarForcing_G1[key])
    else:
        print('Loading EBM results (solarForcing experiment, G1): ' + gmf.modelNames[key])
        results_solarForcing_G1[key] = np.load('npyFiles/EBM_results_solarForcing_G1_' + key + '.npy').item()

results_surfaceFlux_G1 = OrderedDict()
for key in EI_surfaceFlux_G1.keys():
    if not(loadFromFile_results_surfaceFlux_G1[key]):
        print('Running EBM based on output from GCM (surfaceFlux experiment, G1): ' + gmf.modelNames[key])
        results_surfaceFlux_G1[key] = ebm.moistEBM_main(dict_a[key], dict_b[key], EI_surfaceFlux_G1[key], latDict[key], lat_bndsDict[key], nmax=100000)
        np.save('npyFiles/EBM_results_surfaceFlux_G1_' + key + '.npy', results_surfaceFlux_G1[key])
    else:
        print('Loading EBM results (surfaceFlux experiment, G1): ' + gmf.modelNames[key])
        results_surfaceFlux_G1[key] = np.load('npyFiles/EBM_results_surfaceFlux_G1_' + key + '.npy').item()

results_LWCRE_G1 = OrderedDict()
for key in EI_LWCRE_G1.keys():
    if not(loadFromFile_results_LWCRE_G1[key]):
        print('Running EBM based on output from GCM (LWCRE experiment, G1): ' + gmf.modelNames[key])
        results_LWCRE_G1[key] = ebm.moistEBM_main(dict_a[key], dict_b[key], EI_LWCRE_G1[key], latDict[key], lat_bndsDict[key], nmax=100000)
        np.save('npyFiles/EBM_results_LWCRE_G1_' + key + '.npy', results_LWCRE_G1[key])
    else:
        print('Loading EBM results (LWCRE experiment, G1): ' + gmf.modelNames[key])
        results_LWCRE_G1[key] = np.load('npyFiles/EBM_results_LWCRE_G1_' + key + '.npy').item()

results_greenhouse_G1 = OrderedDict() #This time use the piControl energy input term, and the G1 bPrime
for key in EI_LWCRE_G1.keys():
    if not(loadFromFile_results_greenhouse_G1[key]):
        print('Running EBM based on output from GCM (greenhouse experiment, G1): ' + gmf.modelNames[key])
        results_greenhouse_G1[key] = ebm.moistEBM_main(dict_a[key], dict_bPrime_G1[key], EI_PI[key], latDict[key], lat_bndsDict[key], nmax=100000)
        np.save('npyFiles/EBM_results_greenhouse_G1_' + key + '.npy', results_greenhouse_G1[key])
    else:
        print('Loading EBM results (greenhouse experiment, G1): ' + gmf.modelNames[key])
        results_greenhouse_G1[key] = np.load('npyFiles/EBM_results_greenhouse_G1_' + key + '.npy').item()        
        
#Now the abrupt4xCO2 cases
results_APRPcloud_A4 = OrderedDict()
for key in EI_APRPcloud_A4.keys():
    if not(loadFromFile_results_APRPcloud_A4[key]):
        print('Running EBM based on output from GCM (APRPcloud experiment, A4): ' + gmf.modelNames[key])
        results_APRPcloud_A4[key] = ebm.moistEBM_main(dict_a[key], dict_b[key], EI_APRPcloud_A4[key], latDict[key], lat_bndsDict[key], nmax=100000)
        np.save('npyFiles/EBM_results_APRPcloud_A4_' + key + '.npy', results_APRPcloud_A4[key])
    else:
        print('Loading EBM results (APRPcloud experiment, A4): ' + gmf.modelNames[key])
        results_APRPcloud_A4[key] = np.load('npyFiles/EBM_results_APRPcloud_A4_' + key + '.npy').item()
        
results_APRPnoncloud_A4 = OrderedDict()
for key in EI_APRPnoncloud_A4.keys():
    if not(loadFromFile_results_APRPnoncloud_A4[key]):
        print('Running EBM based on output from GCM (APRPnoncloud experiment, A4): ' + gmf.modelNames[key])
        results_APRPnoncloud_A4[key] = ebm.moistEBM_main(dict_a[key], dict_b[key], EI_APRPnoncloud_A4[key], latDict[key], lat_bndsDict[key], nmax=100000)
        np.save('npyFiles/EBM_results_APRPnoncloud_A4_' + key + '.npy', results_APRPnoncloud_A4[key])
    else:
        print('Loading EBM results (APRPnoncloud experiment, A4): ' + gmf.modelNames[key])
        results_APRPnoncloud_A4[key] = np.load('npyFiles/EBM_results_APRPnoncloud_A4_' + key + '.npy').item()

results_APRPsurface_A4 = OrderedDict()
for key in EI_APRPsurface_A4.keys():
    if not(loadFromFile_results_APRPsurface_A4[key]):
        print('Running EBM based on output from GCM (APRPsurface experiment, A4): ' + gmf.modelNames[key])
        results_APRPsurface_A4[key] = ebm.moistEBM_main(dict_a[key], dict_b[key], EI_APRPsurface_A4[key], latDict[key], lat_bndsDict[key], nmax=100000)
        np.save('npyFiles/EBM_results_APRPsurface_A4_' + key + '.npy', results_APRPsurface_A4[key])
    else:
        print('Loading EBM results (APRPsurface experiment, A4): ' + gmf.modelNames[key])
        results_APRPsurface_A4[key] = np.load('npyFiles/EBM_results_APRPsurface_A4_' + key + '.npy').item()

results_solarForcing_A4 = OrderedDict()
for key in EI_solarForcing_A4.keys():
    if not(loadFromFile_results_solarForcing_A4[key]):
        print('Running EBM based on output from GCM (solarForcing experiment, A4): ' + gmf.modelNames[key])
        results_solarForcing_A4[key] = ebm.moistEBM_main(dict_a[key], dict_b[key], EI_solarForcing_A4[key], latDict[key], lat_bndsDict[key], nmax=100000)
        np.save('npyFiles/EBM_results_solarForcing_A4_' + key + '.npy', results_solarForcing_A4[key])
    else:
        print('Loading EBM results (solarForcing experiment, A4): ' + gmf.modelNames[key])
        results_solarForcing_A4[key] = np.load('npyFiles/EBM_results_solarForcing_A4_' + key + '.npy').item()

results_surfaceFlux_A4 = OrderedDict()
for key in EI_surfaceFlux_A4.keys():
    if not(loadFromFile_results_surfaceFlux_A4[key]):
        print('Running EBM based on output from GCM (surfaceFlux experiment, A4): ' + gmf.modelNames[key])
        results_surfaceFlux_A4[key] = ebm.moistEBM_main(dict_a[key], dict_b[key], EI_surfaceFlux_A4[key], latDict[key], lat_bndsDict[key], nmax=100000)
        np.save('npyFiles/EBM_results_surfaceFlux_A4_' + key + '.npy', results_surfaceFlux_A4[key])
    else:
        print('Loading EBM results (surfaceFlux experiment, A4): ' + gmf.modelNames[key])
        results_surfaceFlux_A4[key] = np.load('npyFiles/EBM_results_surfaceFlux_A4_' + key + '.npy').item()

results_LWCRE_A4 = OrderedDict()
for key in EI_LWCRE_A4.keys():
    if not(loadFromFile_results_LWCRE_A4[key]):
        print('Running EBM based on output from GCM (LWCRE experiment, A4): ' + gmf.modelNames[key])
        results_LWCRE_A4[key] = ebm.moistEBM_main(dict_a[key], dict_b[key], EI_LWCRE_A4[key], latDict[key], lat_bndsDict[key], nmax=100000)
        np.save('npyFiles/EBM_results_LWCRE_A4_' + key + '.npy', results_LWCRE_A4[key])
    else:
        print('Loading EBM results (LWCRE experiment, A4): ' + gmf.modelNames[key])
        results_LWCRE_A4[key] = np.load('npyFiles/EBM_results_LWCRE_A4_' + key + '.npy').item()

results_greenhouse_A4 = OrderedDict() #This time use the piControl energy input term, and the A4 bPrime
for key in EI_LWCRE_A4.keys():
    if not(loadFromFile_results_greenhouse_A4[key]):
        print('Running EBM based on output from GCM (greenhouse experiment, A4): ' + gmf.modelNames[key])
        results_greenhouse_A4[key] = ebm.moistEBM_main(dict_a[key], dict_bPrime_A4[key], EI_PI[key], latDict[key], lat_bndsDict[key], nmax=100000)
        np.save('npyFiles/EBM_results_greenhouse_A4_' + key + '.npy', results_greenhouse_A4[key])
    else:
        print('Loading EBM results (greenhouse experiment, A4): ' + gmf.modelNames[key])
        results_greenhouse_A4[key] = np.load('npyFiles/EBM_results_greenhouse_A4_' + key + '.npy').item()               
        
        
        
        
        
         
#####   POST-PROCESSING   #####
        


# Correct EBM results for northward energy transport at North Pole
# (In the EBM, this is caused by energy loss from the finite difference derivatives)
# (Append 0 transport at South Pole first)
correctedNorthwardTransport_PI = OrderedDict()
for key, value in results_PI.items():
    correctedNorthwardTransport_PI[key] = gmf.correctNorthPoleTransport(np.insert(value['NorthTransport'],0,0), lat_bndsDict[key])

correctedNorthwardTransport_G1 = OrderedDict()
for key, value in results_G1.items():
    correctedNorthwardTransport_G1[key] = gmf.correctNorthPoleTransport(np.insert(value['NorthTransport'],0,0), lat_bndsDict[key])

correctedNorthwardTransport_A4 = OrderedDict()
for key, value in results_A4.items():
    correctedNorthwardTransport_A4[key] = gmf.correctNorthPoleTransport(np.insert(value['NorthTransport'],0,0), lat_bndsDict[key]) 




# For comparisons between different runs: take differences
correctedNorthwardTransport_G1minusPI = OrderedDict()
for key, value in correctedNorthwardTransport_G1.items():
    correctedNorthwardTransport_G1minusPI[key] = value - correctedNorthwardTransport_PI[key]     
    
correctedNorthwardTransport_A4minusPI = OrderedDict()
for key, value in correctedNorthwardTransport_A4.items():
    correctedNorthwardTransport_A4minusPI[key] = value - correctedNorthwardTransport_PI[key]     
        
        
        

# Obtain change in energy transport at equator from EBM results (wait--am I doing this right? Do I need boundary latitudes?)
EBM_northTransport_Equator_G1minusPI = OrderedDict()
for key, value in correctedNorthwardTransport_G1minusPI.items():
    EBM_northTransport_Equator_G1minusPI[key] = np.interp(0, lat_bndsDict[key], value)
    
EBM_northTransport_Equator_A4minusPI = OrderedDict()
for key, value in correctedNorthwardTransport_A4minusPI.items():
    EBM_northTransport_Equator_A4minusPI[key] = np.interp(0, lat_bndsDict[key], value)

# Load the cross-equatorial energy flux change from "v2_meridionalEnergyTransport" script
GCM_northTransport_Equator_G1minusPI_notSubsetted = np.load('npyFiles/v2_GCM_northTransport_equator_G1minusPI.npy').item()
GCM_northTransport_Equator_A4minusPI_notSubsetted = np.load('npyFiles/v2_GCM_northTransport_equator_A4minusPI.npy').item()

#Subset the GCM results to only those models for which I have EBM results
GCM_northTransport_Equator_G1minusPI = OrderedDict()
for key in EBM_northTransport_Equator_G1minusPI.keys():
    GCM_northTransport_Equator_G1minusPI[key] = GCM_northTransport_Equator_G1minusPI_notSubsetted[key]
    
GCM_northTransport_Equator_A4minusPI = OrderedDict()
for key in EBM_northTransport_Equator_A4minusPI.keys():
    GCM_northTransport_Equator_A4minusPI[key] = GCM_northTransport_Equator_A4minusPI_notSubsetted[key]

#Calculate correlation coefficients between cross-equator transport change from GCM and EBMs
r_Equator_G1minusPI = np.corrcoef(EBM_northTransport_Equator_G1minusPI.values(), 
                                  GCM_northTransport_Equator_G1minusPI.values())[0,1]
r_Equator_A4minusPI = np.corrcoef(EBM_northTransport_Equator_A4minusPI.values(), 
                                  GCM_northTransport_Equator_A4minusPI.values())[0,1]
        
        

#Do the same thing for 40 N and S

# Obtain change in energy transport from EBM results
EBM_northTransport_40N_G1minusPI = OrderedDict()
for key, value in correctedNorthwardTransport_G1minusPI.items():
    #print(key)
    EBM_northTransport_40N_G1minusPI[key] = np.interp(40, lat_bndsDict[key], value)
    #print(EBM_northTransport_40N_G1minusPI[key])    
    
EBM_northTransport_40N_A4minusPI = OrderedDict()
for key, value in correctedNorthwardTransport_A4minusPI.items():
    EBM_northTransport_40N_A4minusPI[key] = np.interp(40, lat_bndsDict[key], value)

EBM_northTransport_40S_G1minusPI = OrderedDict()
for key, value in correctedNorthwardTransport_G1minusPI.items():
    EBM_northTransport_40S_G1minusPI[key] = np.interp(-40, lat_bndsDict[key], value)    
    
EBM_northTransport_40S_A4minusPI = OrderedDict()
for key, value in correctedNorthwardTransport_A4minusPI.items():
    EBM_northTransport_40S_A4minusPI[key] = np.interp(-40, lat_bndsDict[key], value)
    
# Get the same things from the GCM results. 
GCM_northTransport_40N_G1minusPI_notSubsetted = np.load('npyFiles/v2_GCM_northTransport_40N_G1minusPI.npy').item()
GCM_northTransport_40N_A4minusPI_notSubsetted = np.load('npyFiles/v2_GCM_northTransport_40N_A4minusPI.npy').item()
GCM_northTransport_40S_G1minusPI_notSubsetted = np.load('npyFiles/v2_GCM_northTransport_40S_G1minusPI.npy').item()
GCM_northTransport_40S_A4minusPI_notSubsetted = np.load('npyFiles/v2_GCM_northTransport_40S_A4minusPI.npy').item()

#Subset the GCM results to only those models for which I have EBM results
GCM_northTransport_40N_G1minusPI = OrderedDict()
for key in EBM_northTransport_40N_G1minusPI.keys():
    GCM_northTransport_40N_G1minusPI[key] = GCM_northTransport_40N_G1minusPI_notSubsetted[key]
    
GCM_northTransport_40N_A4minusPI = OrderedDict()
for key in EBM_northTransport_40N_A4minusPI.keys():
    GCM_northTransport_40N_A4minusPI[key] = GCM_northTransport_40N_A4minusPI_notSubsetted[key]
    
GCM_northTransport_40S_G1minusPI = OrderedDict()
for key in EBM_northTransport_40S_G1minusPI.keys():
    GCM_northTransport_40S_G1minusPI[key] = GCM_northTransport_40S_G1minusPI_notSubsetted[key]
    
GCM_northTransport_40S_A4minusPI = OrderedDict()
for key in EBM_northTransport_40S_A4minusPI.keys():
    GCM_northTransport_40S_A4minusPI[key] = GCM_northTransport_40S_A4minusPI_notSubsetted[key]

    
#Calculate correlation coefficients (together for both 40N and 40S)
EBM_40NS_G1minusPI = np.concatenate((EBM_northTransport_40S_G1minusPI.values(), EBM_northTransport_40N_G1minusPI.values()))
GCM_40NS_G1minusPI = np.concatenate((GCM_northTransport_40S_G1minusPI.values(), GCM_northTransport_40N_G1minusPI.values()))
r_40NS_G1minusPI = np.corrcoef(EBM_40NS_G1minusPI, GCM_40NS_G1minusPI)[0,1]

EBM_40NS_A4minusPI = np.concatenate((EBM_northTransport_40S_A4minusPI.values(), EBM_northTransport_40N_A4minusPI.values()))
GCM_40NS_A4minusPI = np.concatenate((GCM_northTransport_40S_A4minusPI.values(), GCM_northTransport_40N_A4minusPI.values()))
r_40NS_A4minusPI = np.corrcoef(EBM_40NS_A4minusPI, GCM_40NS_A4minusPI)[0,1]
     
             


# Seems to be an artificially high correlation from 2 clusters in the G1 - piControl case. Redo this in terms of 
# poleward, rather than northward, transport. 
EBM_southTransport_40S_G1minusPI = OrderedDict()
GCM_southTransport_40S_G1minusPI = OrderedDict()
for key in EBM_northTransport_40S_G1minusPI.keys():
    EBM_southTransport_40S_G1minusPI[key] = -1*EBM_northTransport_40S_G1minusPI[key]
    GCM_southTransport_40S_G1minusPI[key] = -1*GCM_northTransport_40S_G1minusPI[key]
    
EBM_40NS_G1minusPI_p = np.concatenate((EBM_southTransport_40S_G1minusPI.values(), EBM_northTransport_40N_G1minusPI.values()))
GCM_40NS_G1minusPI_p = np.concatenate((GCM_southTransport_40S_G1minusPI.values(), GCM_northTransport_40N_G1minusPI.values()))
r_40NS_G1minusPI_p = np.corrcoef(EBM_40NS_G1minusPI_p, GCM_40NS_G1minusPI_p)[0,1]    

#Same thing for A4
EBM_southTransport_40S_A4minusPI = OrderedDict()
GCM_southTransport_40S_A4minusPI = OrderedDict()
for key in EBM_northTransport_40S_A4minusPI.keys():
    EBM_southTransport_40S_A4minusPI[key] = -1*EBM_northTransport_40S_A4minusPI[key]
    GCM_southTransport_40S_A4minusPI[key] = -1*GCM_northTransport_40S_A4minusPI[key]
    
EBM_40NS_A4minusPI_p = np.concatenate((EBM_southTransport_40S_A4minusPI.values(), EBM_northTransport_40N_A4minusPI.values()))
GCM_40NS_A4minusPI_p = np.concatenate((GCM_southTransport_40S_A4minusPI.values(), GCM_northTransport_40N_A4minusPI.values()))
r_40NS_A4minusPI_p = np.corrcoef(EBM_40NS_A4minusPI_p, GCM_40NS_A4minusPI_p)[0,1]    



#####   POST-PROCESSING FOR THE SINGLE-PERTURBATION EXPERIMENTS   #####

#Apply the NP/SP correction to the energy transport term
correctedNorthwardTransport_APRPcloud_G1 = OrderedDict()
for key, value in results_APRPcloud_G1.items():
    correctedNorthwardTransport_APRPcloud_G1[key] = gmf.correctNorthPoleTransport(np.insert(value['NorthTransport'],0,0), lat_bndsDict[key])

correctedNorthwardTransport_APRPnoncloud_G1 = OrderedDict()
for key, value in results_APRPnoncloud_G1.items():
    correctedNorthwardTransport_APRPnoncloud_G1[key] = gmf.correctNorthPoleTransport(np.insert(value['NorthTransport'],0,0), lat_bndsDict[key])
    
correctedNorthwardTransport_APRPsurface_G1 = OrderedDict()
for key, value in results_APRPsurface_G1.items():
    correctedNorthwardTransport_APRPsurface_G1[key] = gmf.correctNorthPoleTransport(np.insert(value['NorthTransport'],0,0), lat_bndsDict[key])
    
correctedNorthwardTransport_solarForcing_G1 = OrderedDict()
for key, value in results_solarForcing_G1.items():
    correctedNorthwardTransport_solarForcing_G1[key] = gmf.correctNorthPoleTransport(np.insert(value['NorthTransport'],0,0), lat_bndsDict[key])
    
correctedNorthwardTransport_surfaceFlux_G1 = OrderedDict()
for key, value in results_surfaceFlux_G1.items():
    correctedNorthwardTransport_surfaceFlux_G1[key] = gmf.correctNorthPoleTransport(np.insert(value['NorthTransport'],0,0), lat_bndsDict[key])
    
correctedNorthwardTransport_LWCRE_G1 = OrderedDict()
for key, value in results_LWCRE_G1.items():
    correctedNorthwardTransport_LWCRE_G1[key] = gmf.correctNorthPoleTransport(np.insert(value['NorthTransport'],0,0), lat_bndsDict[key])
    
correctedNorthwardTransport_greenhouse_G1 = OrderedDict()
for key, value in results_greenhouse_G1.items():
    correctedNorthwardTransport_greenhouse_G1[key] = gmf.correctNorthPoleTransport(np.insert(value['NorthTransport'],0,0), lat_bndsDict[key])
    
#Abrupt4xCO2 versions    
correctedNorthwardTransport_APRPcloud_A4 = OrderedDict()
for key, value in results_APRPcloud_A4.items():
    correctedNorthwardTransport_APRPcloud_A4[key] = gmf.correctNorthPoleTransport(np.insert(value['NorthTransport'],0,0), lat_bndsDict[key])

correctedNorthwardTransport_APRPnoncloud_A4 = OrderedDict()
for key, value in results_APRPnoncloud_A4.items():
    correctedNorthwardTransport_APRPnoncloud_A4[key] = gmf.correctNorthPoleTransport(np.insert(value['NorthTransport'],0,0), lat_bndsDict[key])
    
correctedNorthwardTransport_APRPsurface_A4 = OrderedDict()
for key, value in results_APRPsurface_A4.items():
    correctedNorthwardTransport_APRPsurface_A4[key] = gmf.correctNorthPoleTransport(np.insert(value['NorthTransport'],0,0), lat_bndsDict[key])
    
correctedNorthwardTransport_solarForcing_A4 = OrderedDict()
for key, value in results_solarForcing_A4.items():
    correctedNorthwardTransport_solarForcing_A4[key] = gmf.correctNorthPoleTransport(np.insert(value['NorthTransport'],0,0), lat_bndsDict[key])
    
correctedNorthwardTransport_surfaceFlux_A4 = OrderedDict()
for key, value in results_surfaceFlux_A4.items():
    correctedNorthwardTransport_surfaceFlux_A4[key] = gmf.correctNorthPoleTransport(np.insert(value['NorthTransport'],0,0), lat_bndsDict[key])
    
correctedNorthwardTransport_LWCRE_A4 = OrderedDict()
for key, value in results_LWCRE_A4.items():
    correctedNorthwardTransport_LWCRE_A4[key] = gmf.correctNorthPoleTransport(np.insert(value['NorthTransport'],0,0), lat_bndsDict[key])
    
correctedNorthwardTransport_greenhouse_A4 = OrderedDict()
for key, value in results_greenhouse_A4.items():
    correctedNorthwardTransport_greenhouse_A4[key] = gmf.correctNorthPoleTransport(np.insert(value['NorthTransport'],0,0), lat_bndsDict[key])    

#Now get difference between each experiment's energy transport and the control run
northwardTransportDiff_APRPcloud_G1 = OrderedDict()
for key, value in correctedNorthwardTransport_APRPcloud_G1.items():
    northwardTransportDiff_APRPcloud_G1[key] = value - correctedNorthwardTransport_PI[key]     

northwardTransportDiff_APRPnoncloud_G1 = OrderedDict()
for key, value in correctedNorthwardTransport_APRPnoncloud_G1.items():
    northwardTransportDiff_APRPnoncloud_G1[key] = value - correctedNorthwardTransport_PI[key]     

northwardTransportDiff_APRPsurface_G1 = OrderedDict()
for key, value in correctedNorthwardTransport_APRPsurface_G1.items():
    northwardTransportDiff_APRPsurface_G1[key] = value - correctedNorthwardTransport_PI[key]     

northwardTransportDiff_solarForcing_G1 = OrderedDict()
for key, value in correctedNorthwardTransport_solarForcing_G1.items():
    northwardTransportDiff_solarForcing_G1[key] = value - correctedNorthwardTransport_PI[key]     

northwardTransportDiff_surfaceFlux_G1 = OrderedDict()
for key, value in correctedNorthwardTransport_surfaceFlux_G1.items():
    northwardTransportDiff_surfaceFlux_G1[key] = value - correctedNorthwardTransport_PI[key]     

northwardTransportDiff_LWCRE_G1 = OrderedDict()
for key, value in correctedNorthwardTransport_LWCRE_G1.items():
    northwardTransportDiff_LWCRE_G1[key] = value - correctedNorthwardTransport_PI[key]     

northwardTransportDiff_greenhouse_G1 = OrderedDict()
for key, value in correctedNorthwardTransport_greenhouse_G1.items():
    northwardTransportDiff_greenhouse_G1[key] = value - correctedNorthwardTransport_PI[key]         
    
#Abrupt4xCO2 versions    
northwardTransportDiff_APRPcloud_A4 = OrderedDict()
for key, value in correctedNorthwardTransport_APRPcloud_A4.items():
    northwardTransportDiff_APRPcloud_A4[key] = value - correctedNorthwardTransport_PI[key]     

northwardTransportDiff_APRPnoncloud_A4 = OrderedDict()
for key, value in correctedNorthwardTransport_APRPnoncloud_A4.items():
    northwardTransportDiff_APRPnoncloud_A4[key] = value - correctedNorthwardTransport_PI[key]     

northwardTransportDiff_APRPsurface_A4 = OrderedDict()
for key, value in correctedNorthwardTransport_APRPsurface_A4.items():
    northwardTransportDiff_APRPsurface_A4[key] = value - correctedNorthwardTransport_PI[key]     

northwardTransportDiff_solarForcing_A4 = OrderedDict()
for key, value in correctedNorthwardTransport_solarForcing_A4.items():
    northwardTransportDiff_solarForcing_A4[key] = value - correctedNorthwardTransport_PI[key]     

northwardTransportDiff_surfaceFlux_A4 = OrderedDict()
for key, value in correctedNorthwardTransport_surfaceFlux_A4.items():
    northwardTransportDiff_surfaceFlux_A4[key] = value - correctedNorthwardTransport_PI[key]     

northwardTransportDiff_LWCRE_A4 = OrderedDict()
for key, value in correctedNorthwardTransport_LWCRE_A4.items():
    northwardTransportDiff_LWCRE_A4[key] = value - correctedNorthwardTransport_PI[key]     

northwardTransportDiff_greenhouse_A4 = OrderedDict()
for key, value in correctedNorthwardTransport_greenhouse_A4.items():
    northwardTransportDiff_greenhouse_A4[key] = value - correctedNorthwardTransport_PI[key]            

#Now, interpolate to latitudes of interest (equator, 40 N, 40 S)

#Equator: G1 only--poor correlation for abrupt4xCO2
EBM_northTransportDiff_Equator_APRPcloud_G1 = OrderedDict()
for key, value in northwardTransportDiff_APRPcloud_G1.items():
    EBM_northTransportDiff_Equator_APRPcloud_G1[key] = np.interp(0, lat_bndsDict[key], value)

EBM_northTransportDiff_Equator_APRPnoncloud_G1 = OrderedDict()
for key, value in northwardTransportDiff_APRPnoncloud_G1.items():
    EBM_northTransportDiff_Equator_APRPnoncloud_G1[key] = np.interp(0, lat_bndsDict[key], value)
    
EBM_northTransportDiff_Equator_APRPsurface_G1 = OrderedDict()
for key, value in northwardTransportDiff_APRPsurface_G1.items():
    EBM_northTransportDiff_Equator_APRPsurface_G1[key] = np.interp(0, lat_bndsDict[key], value)

EBM_northTransportDiff_Equator_solarForcing_G1 = OrderedDict()
for key, value in northwardTransportDiff_solarForcing_G1.items():
    EBM_northTransportDiff_Equator_solarForcing_G1[key] = np.interp(0, lat_bndsDict[key], value)
    
EBM_northTransportDiff_Equator_surfaceFlux_G1 = OrderedDict()
for key, value in northwardTransportDiff_surfaceFlux_G1.items():
    EBM_northTransportDiff_Equator_surfaceFlux_G1[key] = np.interp(0, lat_bndsDict[key], value)

EBM_northTransportDiff_Equator_LWCRE_G1 = OrderedDict()
for key, value in northwardTransportDiff_LWCRE_G1.items():
    EBM_northTransportDiff_Equator_LWCRE_G1[key] = np.interp(0, lat_bndsDict[key], value)

EBM_northTransportDiff_Equator_greenhouse_G1 = OrderedDict()
for key, value in northwardTransportDiff_greenhouse_G1.items():
    EBM_northTransportDiff_Equator_greenhouse_G1[key] = np.interp(0, lat_bndsDict[key], value)    
    
# 40 N: Northward transport
EBM_northTransportDiff_40N_APRPcloud_G1 = OrderedDict()
for key, value in northwardTransportDiff_APRPcloud_G1.items():
    EBM_northTransportDiff_40N_APRPcloud_G1[key] = np.interp(40, lat_bndsDict[key], value)

EBM_northTransportDiff_40N_APRPnoncloud_G1 = OrderedDict()
for key, value in northwardTransportDiff_APRPnoncloud_G1.items():
    EBM_northTransportDiff_40N_APRPnoncloud_G1[key] = np.interp(40, lat_bndsDict[key], value)
    
EBM_northTransportDiff_40N_APRPsurface_G1 = OrderedDict()
for key, value in northwardTransportDiff_APRPsurface_G1.items():
    EBM_northTransportDiff_40N_APRPsurface_G1[key] = np.interp(40, lat_bndsDict[key], value)

EBM_northTransportDiff_40N_solarForcing_G1 = OrderedDict()
for key, value in northwardTransportDiff_solarForcing_G1.items():
    EBM_northTransportDiff_40N_solarForcing_G1[key] = np.interp(40, lat_bndsDict[key], value)
    
EBM_northTransportDiff_40N_surfaceFlux_G1 = OrderedDict()
for key, value in northwardTransportDiff_surfaceFlux_G1.items():
    EBM_northTransportDiff_40N_surfaceFlux_G1[key] = np.interp(40, lat_bndsDict[key], value)

EBM_northTransportDiff_40N_LWCRE_G1 = OrderedDict()
for key, value in northwardTransportDiff_LWCRE_G1.items():
    EBM_northTransportDiff_40N_LWCRE_G1[key] = np.interp(40, lat_bndsDict[key], value)

EBM_northTransportDiff_40N_greenhouse_G1 = OrderedDict()
for key, value in northwardTransportDiff_greenhouse_G1.items():
    EBM_northTransportDiff_40N_greenhouse_G1[key] = np.interp(40, lat_bndsDict[key], value)    
    
# Abrupt4xCO2 versions    
EBM_northTransportDiff_40N_APRPcloud_A4 = OrderedDict()
for key, value in northwardTransportDiff_APRPcloud_A4.items():
    EBM_northTransportDiff_40N_APRPcloud_A4[key] = np.interp(40, lat_bndsDict[key], value)

EBM_northTransportDiff_40N_APRPnoncloud_A4 = OrderedDict()
for key, value in northwardTransportDiff_APRPnoncloud_A4.items():
    EBM_northTransportDiff_40N_APRPnoncloud_A4[key] = np.interp(40, lat_bndsDict[key], value)
    
EBM_northTransportDiff_40N_APRPsurface_A4 = OrderedDict()
for key, value in northwardTransportDiff_APRPsurface_A4.items():
    EBM_northTransportDiff_40N_APRPsurface_A4[key] = np.interp(40, lat_bndsDict[key], value)

EBM_northTransportDiff_40N_solarForcing_A4 = OrderedDict()
for key, value in northwardTransportDiff_solarForcing_A4.items():
    EBM_northTransportDiff_40N_solarForcing_A4[key] = np.interp(40, lat_bndsDict[key], value)
    
EBM_northTransportDiff_40N_surfaceFlux_A4 = OrderedDict()
for key, value in northwardTransportDiff_surfaceFlux_A4.items():
    EBM_northTransportDiff_40N_surfaceFlux_A4[key] = np.interp(40, lat_bndsDict[key], value)

EBM_northTransportDiff_40N_LWCRE_A4 = OrderedDict()
for key, value in northwardTransportDiff_LWCRE_A4.items():
    EBM_northTransportDiff_40N_LWCRE_A4[key] = np.interp(40, lat_bndsDict[key], value)

EBM_northTransportDiff_40N_greenhouse_A4 = OrderedDict()
for key, value in northwardTransportDiff_greenhouse_A4.items():
    EBM_northTransportDiff_40N_greenhouse_A4[key] = np.interp(40, lat_bndsDict[key], value)    
    
    
# 40 S: Southward transport (poleward)
EBM_southTransportDiff_40S_APRPcloud_G1 = OrderedDict()
for key, value in northwardTransportDiff_APRPcloud_G1.items():
    EBM_southTransportDiff_40S_APRPcloud_G1[key] = -np.interp(-40, lat_bndsDict[key], value)

EBM_southTransportDiff_40S_APRPnoncloud_G1 = OrderedDict()
for key, value in northwardTransportDiff_APRPnoncloud_G1.items():
    EBM_southTransportDiff_40S_APRPnoncloud_G1[key] = -np.interp(-40, lat_bndsDict[key], value)
    
EBM_southTransportDiff_40S_APRPsurface_G1 = OrderedDict()
for key, value in northwardTransportDiff_APRPsurface_G1.items():
    EBM_southTransportDiff_40S_APRPsurface_G1[key] = -np.interp(-40, lat_bndsDict[key], value)

EBM_southTransportDiff_40S_solarForcing_G1 = OrderedDict()
for key, value in northwardTransportDiff_solarForcing_G1.items():
    EBM_southTransportDiff_40S_solarForcing_G1[key] = -np.interp(-40, lat_bndsDict[key], value)
    
EBM_southTransportDiff_40S_surfaceFlux_G1 = OrderedDict()
for key, value in northwardTransportDiff_surfaceFlux_G1.items():
    EBM_southTransportDiff_40S_surfaceFlux_G1[key] = -np.interp(-40, lat_bndsDict[key], value)

EBM_southTransportDiff_40S_LWCRE_G1 = OrderedDict()
for key, value in northwardTransportDiff_LWCRE_G1.items():
    EBM_southTransportDiff_40S_LWCRE_G1[key] = -np.interp(-40, lat_bndsDict[key], value)

EBM_southTransportDiff_40S_greenhouse_G1 = OrderedDict()
for key, value in northwardTransportDiff_greenhouse_G1.items():
    EBM_southTransportDiff_40S_greenhouse_G1[key] = -np.interp(-40, lat_bndsDict[key], value)    
    
# Abrupt4xCO2 versions    
EBM_southTransportDiff_40S_APRPcloud_A4 = OrderedDict()
for key, value in northwardTransportDiff_APRPcloud_A4.items():
    EBM_southTransportDiff_40S_APRPcloud_A4[key] = -np.interp(-40, lat_bndsDict[key], value)

EBM_southTransportDiff_40S_APRPnoncloud_A4 = OrderedDict()
for key, value in northwardTransportDiff_APRPnoncloud_A4.items():
    EBM_southTransportDiff_40S_APRPnoncloud_A4[key] = -np.interp(-40, lat_bndsDict[key], value)
    
EBM_southTransportDiff_40S_APRPsurface_A4 = OrderedDict()
for key, value in northwardTransportDiff_APRPsurface_A4.items():
    EBM_southTransportDiff_40S_APRPsurface_A4[key] = -np.interp(-40, lat_bndsDict[key], value)

EBM_southTransportDiff_40S_solarForcing_A4 = OrderedDict()
for key, value in northwardTransportDiff_solarForcing_A4.items():
    EBM_southTransportDiff_40S_solarForcing_A4[key] = -np.interp(-40, lat_bndsDict[key], value)
    
EBM_southTransportDiff_40S_surfaceFlux_A4 = OrderedDict()
for key, value in northwardTransportDiff_surfaceFlux_A4.items():
    EBM_southTransportDiff_40S_surfaceFlux_A4[key] = -np.interp(-40, lat_bndsDict[key], value)

EBM_southTransportDiff_40S_LWCRE_A4 = OrderedDict()
for key, value in northwardTransportDiff_LWCRE_A4.items():
    EBM_southTransportDiff_40S_LWCRE_A4[key] = -np.interp(-40, lat_bndsDict[key], value)

EBM_southTransportDiff_40S_greenhouse_A4 = OrderedDict()
for key, value in northwardTransportDiff_greenhouse_A4.items():
    EBM_southTransportDiff_40S_greenhouse_A4[key] = -np.interp(-40, lat_bndsDict[key], value)  



        
        
        
#####   PLOTS   #####
        
#11-14-16: "v3" includes CESM model, revised a'/b' and rlutcs corrections. 
#          "v2" was earlier round of revisions that included revised rlut for CCSM4 and Norwegian model, 
#           and corrected interpolation of energy transport to specific latitudes. 
#           More details recorded in git log.


#Figure 5 in paper

#Scatter plot EBM and GCM results together for cross-equatorial energy transport

#G1 minus piControl, equator (Figure 5a in paper)
plt.figure(14)
legendEntries = OrderedDict()
modelNames = OrderedDict()
for key, value in EBM_northTransport_Equator_G1minusPI.items():
    legendEntries[key] = plt.scatter(value/1.e15, GCM_northTransport_Equator_G1minusPI[key]/1.e15, 
                                     s=150, c=gmf.modelColors[key])   
    modelNames[key] = gmf.modelNames[key]                                 
plt.hlines(0, -1, 1, linestyles='dashed')
plt.vlines(0, -1, 1, linestyles='dashed')
plt.plot([-1, 1], [-1, 1], 'k')    #1:1 line
plt.axis([-.15, .15, -.15, .15])
plt.xlabel('EBM')
plt.ylabel('GCMs') 
plt.title('Cross-equatorial energy transport: G1 - piControl (PW) \n $r$ = '+str(round(r_Equator_G1minusPI,2)))
plt.legend(legendEntries.values(), modelNames.values(), frameon=False, scatterpoints=1,fontsize=10,
           loc='center left', bbox_to_anchor=(1, 0.5))
plt.gca().set_aspect(1)
plt.subplots_adjust(left=.005)
plt.savefig('plots/v3_scatterTransportGCMvsEBM_Equator_G1minusPI.pdf')


     
#Scatter plot 40 N/S results together (both 40 N and 40 S on same plot)
#Poleward rather than Northward transport versions

#G1 minus piControl (Figure 5b in paper)
plt.figure(18)
legendEntries = OrderedDict()
legendText = OrderedDict()
for key in correctedNorthwardTransport_G1minusPI.keys():
    legendEntries[key] = plt.scatter(EBM_northTransport_40N_G1minusPI[key]/1.0e15,
                                     GCM_northTransport_40N_G1minusPI[key]/1.0e15, 
                                     s=150, c=gmf.modelColors[key], marker='>')   
    legendEntries[key+'a'] = plt.scatter(EBM_southTransport_40S_G1minusPI[key]/1.0e15, #adding dummy to key to keep order right
                                         GCM_southTransport_40S_G1minusPI[key]/1.0e15, 
                                         s=150, c=gmf.modelColors[key], marker='<')                                         
    legendText[key] = gmf.modelNames[key] + ': 40N'
    legendText[key+'a'] = gmf.modelNames[key] + ': 40S'
plt.hlines(0, -1, 1, linestyles='dashed')
plt.vlines(0, -1, 1, linestyles='dashed')
plt.plot([-1, 1], [-1, 1], 'k')    #1:1 line
plt.axis([-.35, 0, -.35, 0])
plt.xlabel('EBM')
plt.ylabel('GCMs') 
plt.title('Poleward energy transport at 40$^\circ$N/S: G1 - piControl (PW) \n $r$ = '+str(round(r_40NS_G1minusPI_p,2)))
plt.legend(legendEntries.values(), legendText.values(), frameon=False, scatterpoints=1,fontsize=9,           
           loc='center left', bbox_to_anchor=(1, 0.5))
plt.gca().set_aspect(1)
plt.subplots_adjust(left=.005)
plt.savefig('plots/v3_scatterPolewardTransportGCMvsEBM_40NS_G1minusPI.pdf')

#abrupt4xCO2 minus piControl (Figure 5c in paper)
plt.figure(19)
legendEntries = OrderedDict()
legendText = OrderedDict()
for key in correctedNorthwardTransport_A4minusPI.keys():
    legendEntries[key] = plt.scatter(EBM_northTransport_40N_A4minusPI[key]/1.0e15,
                                      GCM_northTransport_40N_A4minusPI[key]/1.0e15, 
                                      s=150, c=gmf.modelColors[key], marker='>')   
    legendEntries[key+'a'] = plt.scatter(EBM_southTransport_40S_A4minusPI[key]/1.0e15, #adding dummy to key to keep order right
                                         GCM_southTransport_40S_A4minusPI[key]/1.0e15, 
                                         s=150, c=gmf.modelColors[key], marker='<')                                         
    legendText[key] = gmf.modelNames[key] + ': 40N'
    legendText[key+'a'] = gmf.modelNames[key] + ': 40S'
plt.hlines(0, -1, 1, linestyles='dashed')
plt.vlines(0, -1, 1, linestyles='dashed')
plt.plot([-1, 1], [-1, 1], 'k')    #1:1 line
plt.axis([-.2, .8, -.2, .8])
plt.xlabel('EBM')
plt.ylabel('GCMs') 
plt.title('Poleward energy transport at 40$^\circ$N/S: abrupt4xCO2 - piControl (PW) \n $r$ = '+str(round(r_40NS_A4minusPI_p,2)))
plt.legend(legendEntries.values(), legendText.values(), frameon=False, scatterpoints=1,fontsize=9,           
           loc='center left', bbox_to_anchor=(1, 0.5))
plt.gca().set_aspect(1)
plt.subplots_adjust(left=.005)
plt.savefig('plots/v3_scatterPolewardTransportGCMvsEBM_40NS_A4minusPI.pdf')





    
    
# Plots of results from the individual perturbation experiments.
# These will need to be scatter plots with 1 through 8 on the x axis (for total and the 7 experiments), 
# modify tick labels to get the text.         
    
# (These are Figures 6-8 in paper)    
    
w,h = plt.figaspect(1./2.5)  #Makes figure window 2.5:1; plot itself approximately that
    
#Equator (G1)    (Figure 6 in paper)
plt.figure(20, figsize=(w,h))
legendEntries = OrderedDict()
legendText = OrderedDict()
#Loop through the different models and plot entry for each experiment
keys = EBM_northTransport_Equator_G1minusPI.keys()
for key in keys:
    legendEntries[key] = plt.scatter(1, EBM_northTransport_Equator_G1minusPI[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(2, EBM_northTransportDiff_Equator_APRPcloud_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(3, EBM_northTransportDiff_Equator_APRPnoncloud_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(4, EBM_northTransportDiff_Equator_APRPsurface_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(5, EBM_northTransportDiff_Equator_solarForcing_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(6, EBM_northTransportDiff_Equator_surfaceFlux_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(7, EBM_northTransportDiff_Equator_LWCRE_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(8, EBM_northTransportDiff_Equator_greenhouse_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    legendText[key] = gmf.modelNames[key]
plt.axis([0, 9, -.08, .08])
plt.gca().set_xticklabels(['', 'all_G1', 'APRPcloud', 'APRPnoncloud', 'APRPsurface', 
                           'solarForcing', 'surfaceFlux', 'LWCRE', 'greenhouse'])
plt.hlines(0,0,9, linestyles='dashed')                           
plt.xlabel('Experiment')
plt.ylabel('Change in energy transport (PW)') 
plt.title('EBM: Northward cross-equatorial energy transport: G1 - piControl')
plt.legend(legendEntries.values(), legendText.values(), frameon=True, loc='upper right',scatterpoints=1,fontsize=10)
plt.savefig('plots/v3_EnergyTransportChangeAttribution_Equator_G1.pdf')

        
        
#40 N (G1) (Figure 7a in paper)
plt.figure(21, figsize=(w,h))
legendEntries = OrderedDict()
legendText = OrderedDict()
#Loop through the different models and plot entry for each experiment
keys = EBM_northTransport_40N_G1minusPI.keys()
for key in keys:
    legendEntries[key] = plt.scatter(1, EBM_northTransport_40N_G1minusPI[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(2, EBM_northTransportDiff_40N_APRPcloud_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(3, EBM_northTransportDiff_40N_APRPnoncloud_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(4, EBM_northTransportDiff_40N_APRPsurface_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(5, EBM_northTransportDiff_40N_solarForcing_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(6, EBM_northTransportDiff_40N_surfaceFlux_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(7, EBM_northTransportDiff_40N_LWCRE_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(8, EBM_northTransportDiff_40N_greenhouse_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    legendText[key] = gmf.modelNames[key]
plt.axis([0, 9, -.6, .4])
plt.gca().set_xticklabels(['', 'all_G1', 'APRPcloud', 'APRPnoncloud', 'APRPsurface', 
                           'solarForcing', 'surfaceFlux', 'LWCRE', 'greenhouse'])
plt.hlines(0,0,9, linestyles='dashed')                           
plt.xlabel('Experiment')
plt.ylabel('Change in energy transport (PW)') 
plt.title('EBM: Poleward energy transport at 40$^\circ$N: G1 - piControl')
plt.legend(legendEntries.values(), legendText.values(), frameon=True, loc='lower right',scatterpoints=1,fontsize=10)
plt.savefig('plots/v3_EnergyTransportChangeAttribution_40N_G1.pdf')

#40 N (abrupt4xCO2) (Figure 7b in paper)
plt.figure(22, figsize=(w,h))
legendEntries = OrderedDict()
legendText = OrderedDict()
#Loop through the different models and plot entry for each experiment
keys = EBM_northTransport_40N_A4minusPI.keys()
for key in keys:
    legendEntries[key] = plt.scatter(1, EBM_northTransport_40N_A4minusPI[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(2, EBM_northTransportDiff_40N_APRPcloud_A4[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(3, EBM_northTransportDiff_40N_APRPnoncloud_A4[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(4, EBM_northTransportDiff_40N_APRPsurface_A4[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(5, EBM_northTransportDiff_40N_solarForcing_A4[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(6, EBM_northTransportDiff_40N_surfaceFlux_A4[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(7, EBM_northTransportDiff_40N_LWCRE_A4[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(8, EBM_northTransportDiff_40N_greenhouse_A4[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    legendText[key] = gmf.modelNames[key]
plt.axis([0, 9, -.3, .7])
plt.gca().set_xticklabels(['', 'all_4xCO2', 'APRPcloud', 'APRPnoncloud', 'APRPsurface', 
                           'solarForcing', 'surfaceFlux', 'LWCRE', 'greenhouse'])
plt.hlines(0,0,9, linestyles='dashed')                           
plt.xlabel('Experiment')
plt.ylabel('Change in energy transport (PW)') 
plt.title('EBM: Poleward energy transport at 40$^\circ$N: abrupt4xCO2 - piControl')
plt.legend(legendEntries.values(), legendText.values(), frameon=True, loc='upper center',scatterpoints=1,fontsize=10)
plt.savefig('plots/v3_EnergyTransportChangeAttribution_40N_Abrupt4xCO2.pdf')
        
#40 S (G1) (Figure 8a in paper)
plt.figure(23, figsize=(w,h))
legendEntries = OrderedDict()
legendText = OrderedDict()
#Loop through the different models and plot entry for each experiment
keys = EBM_northTransport_40S_G1minusPI.keys()
for key in keys:
    legendEntries[key] = plt.scatter(1, EBM_southTransport_40S_G1minusPI[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(2, EBM_southTransportDiff_40S_APRPcloud_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(3, EBM_southTransportDiff_40S_APRPnoncloud_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(4, EBM_southTransportDiff_40S_APRPsurface_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(5, EBM_southTransportDiff_40S_solarForcing_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(6, EBM_southTransportDiff_40S_surfaceFlux_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(7, EBM_southTransportDiff_40S_LWCRE_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(8, EBM_southTransportDiff_40S_greenhouse_G1[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    legendText[key] = gmf.modelNames[key]
plt.axis([0, 9, -.6, .4])
plt.gca().set_xticklabels(['', 'all_G1', 'APRPcloud', 'APRPnoncloud', 'APRPsurface', 
                           'solarForcing', 'surfaceFlux', 'LWCRE', 'greenhouse'])
plt.hlines(0,0,9, linestyles='dashed')                           
plt.xlabel('Experiment')
plt.ylabel('Change in energy transport (PW)') 
plt.title('EBM: Poleward energy transport at 40$^\circ$S: G1 - piControl')
plt.legend(legendEntries.values(), legendText.values(), frameon=True, loc='lower right',scatterpoints=1,fontsize=10)
plt.savefig('plots/v3_EnergyTransportChangeAttribution_40S_G1.pdf')

#40 S (abrupt4xCO2) (Figure 8b in paper)
plt.figure(24, figsize=(w,h))
legendEntries = OrderedDict()
legendText = OrderedDict()
#Loop through the different models and plot entry for each experiment
keys = EBM_southTransport_40S_A4minusPI.keys()
for key in keys:
    legendEntries[key] = plt.scatter(1, EBM_southTransport_40S_A4minusPI[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(2, EBM_southTransportDiff_40S_APRPcloud_A4[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(3, EBM_southTransportDiff_40S_APRPnoncloud_A4[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(4, EBM_southTransportDiff_40S_APRPsurface_A4[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(5, EBM_southTransportDiff_40S_solarForcing_A4[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(6, EBM_southTransportDiff_40S_surfaceFlux_A4[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(7, EBM_southTransportDiff_40S_LWCRE_A4[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    plt.scatter(8, EBM_southTransportDiff_40S_greenhouse_A4[key]/1.0e15, s=50, 
                                     c=gmf.modelColors[key], edgecolor='none')
    legendText[key] = gmf.modelNames[key]
plt.axis([0, 9, -.3, .7])
plt.gca().set_xticklabels(['', 'all_4xCO2', 'APRPcloud', 'APRPnoncloud', 'APRPsurface', 
                           'solarForcing', 'surfaceFlux', 'LWCRE', 'greenhouse'])
plt.hlines(0,0,9, linestyles='dashed')                           
plt.xlabel('Experiment')
plt.ylabel('Change in energy transport (PW)') 
plt.title('EBM: Poleward energy transport at 40$^\circ$S: abrupt4xCO2 - piControl')
plt.legend(legendEntries.values(), legendText.values(), frameon=True, loc='upper center',scatterpoints=1,fontsize=10)
plt.savefig('plots/v3_EnergyTransportChangeAttribution_40S_Abrupt4xCO2.pdf')
        



plt.show()